pub enum ActivityError {
Application(Box<ApplicationFailure>),
Cancelled {
details: Option<FailurePayloads>,
},
WillCompleteAsync,
}Expand description
Returned as errors from activity functions.
Variants
Application(Box<ApplicationFailure>)
Return this error to attach application-failure metadata to an activity failure.
Cancelled
Return this error to indicate your activity is cancelling
Fields

details: Option<FailurePayloads>Optional cancellation details.
WillCompleteAsync
Return this error to indicate that the activity will be completed outside of this activity definition, by an external client.
Implementations
Sourceimpl ActivityError
impl ActivityError
Sourcepub fn cancelled() -> ActivityError
pub fn cancelled() -> ActivityError
Construct a cancelled error without details
Sourcepub fn cancelled_with_details<T>(details: T) -> ActivityErrorwhere
T: Into<FailurePayloads>,
pub fn cancelled_with_details<T>(details: T) -> ActivityErrorwhere
T: Into<FailurePayloads>,
Construct a cancelled error with details that will be converted using the active data converter.
Sourcepub fn application(err: ApplicationFailure) -> ActivityError
pub fn application(err: ApplicationFailure) -> ActivityError
Construct an application activity error.