pub struct ActivityContext { /* private fields */ }Expand description
Used within activities to get info, heartbeat management etc.
Implementations
Sourceimpl ActivityContext
impl ActivityContext
Sourcepub fn new(
worker: Arc<CoreWorker>,
cancellation_token: CancellationToken,
task_queue: String,
task_token: Vec<u8>,
task: Start,
) -> (Self, Vec<Payload>)
pub fn new( worker: Arc<CoreWorker>, cancellation_token: CancellationToken, task_queue: String, task_token: Vec<u8>, task: Start, ) -> (Self, Vec<Payload>)
Construct new Activity Context, returning the context and all arguments to the activity.
Sourcepub async fn cancelled(&self)
pub async fn cancelled(&self)
Returns a future the completes if and when the activity this was called inside has been cancelled
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if this activity has already been cancelled
Sourcepub fn heartbeat_details(&self) -> &[Payload]
pub fn heartbeat_details(&self) -> &[Payload]
Extract heartbeat details from last failed attempt. This is used in combination with retry policy.
Sourcepub fn record_heartbeat(&self, details: Vec<Payload>)
pub fn record_heartbeat(&self, details: Vec<Payload>)
RecordHeartbeat sends heartbeat for the currently executing activity
Sourcepub fn info(&self) -> &ActivityInfo
pub fn info(&self) -> &ActivityInfo
Returns activity info of the executing activity