#[non_exhaustive]pub struct ActivityInfo {Show 16 fields
pub task_token: Vec<u8>,
pub workflow_type: String,
pub workflow_namespace: String,
pub workflow_execution: Option<WorkflowExecution>,
pub activity_id: String,
pub activity_type: String,
pub task_queue: String,
pub heartbeat_timeout: Option<Duration>,
pub scheduled_time: Option<SystemTime>,
pub started_time: Option<SystemTime>,
pub deadline: Option<SystemTime>,
pub attempt: u32,
pub current_attempt_scheduled_time: Option<SystemTime>,
pub retry_policy: Option<RetryPolicy>,
pub is_local: bool,
pub priority: Priority,
}Expand description
Various information about a specific activity attempt.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_token: Vec<u8>An opaque token representing a specific Activity task.
workflow_type: StringThe type of the workflow that invoked this activity.
workflow_namespace: StringThe namespace of the workflow that invoked this activity.
workflow_execution: Option<WorkflowExecution>The execution of the workflow that invoked this activity.
activity_id: StringThe ID of this activity.
activity_type: StringThe type of this activity.
task_queue: StringThe task queue of this activity.
heartbeat_timeout: Option<Duration>The interval within which this activity must heartbeat or be timed out.
scheduled_time: Option<SystemTime>Time activity was scheduled by a workflow.
started_time: Option<SystemTime>Time of activity start.
deadline: Option<SystemTime>Time of activity timeout.
attempt: u32Attempt starts from 1, and increase by 1 for every retry, if retry policy is specified.
current_attempt_scheduled_time: Option<SystemTime>Time this attempt at the activity was scheduled.
retry_policy: Option<RetryPolicy>The retry policy for this activity.
is_local: boolWhether or not this is a local activity.
priority: PriorityPriority of this activity. If unset uses Priority::default.