pub enum ActivityCloseTimeouts {
ScheduleToClose(Duration),
StartToClose(Duration),
Both {
start_to_close: Duration,
schedule_to_close: Duration,
},
}Expand description
The timeouts applied to an activity’s completion.
Variants
ScheduleToClose(Duration)
Total time that a workflow is willing to wait for Activity to complete.
ActivityCloseTimeouts::ScheduleToClose limits the total time of an Activity’s execution
including retries (use ActivityCloseTimeouts::StartToClose to limit the time of a single
attempt).
StartToClose(Duration)
Maximum time of a single Activity execution attempt. Note that the Temporal Server doesn’t
detect Worker process failures directly. It relies on this timeout to detect that an
Activity that didn’t complete on time. So this timeout should be as short as the longest
possible execution of the Activity body. Potentially long running Activities must specify
ActivityOptions::heartbeat_timeout and heartbeat from the activity periodically for timely
failure detection.
Both
Applies both execution-attempt and overall-completion bounds.