#[repr(i32)]pub enum StartChildWorkflowExecutionFailedCause {
Unspecified = 0,
WorkflowAlreadyExists = 1,
}Expand description
Possible causes of failure to start a child workflow
Variants
Implementations
Sourceimpl StartChildWorkflowExecutionFailedCause
impl StartChildWorkflowExecutionFailedCause
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of StartChildWorkflowExecutionFailedCause.
Sourcepub fn from_i32(value: i32) -> Option<StartChildWorkflowExecutionFailedCause>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<StartChildWorkflowExecutionFailedCause>
Use the TryFrom<i32> implementation instead
Converts an i32 to a StartChildWorkflowExecutionFailedCause, or None if value is not a valid variant.
Sourceimpl StartChildWorkflowExecutionFailedCause
impl StartChildWorkflowExecutionFailedCause
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(
value: &str,
) -> Option<StartChildWorkflowExecutionFailedCause>
pub fn from_str_name( value: &str, ) -> Option<StartChildWorkflowExecutionFailedCause>
Creates an enum from field names used in the ProtoBuf definition.