pub enum WorkflowTermination {
Cancelled,
Evicted,
ContinueAsNew(Box<ContinueAsNewWorkflowExecution>),
Failed(Error),
}Expand description
Represents ways a workflow can terminate without producing a normal result.
This is used as the error type in WorkflowResult<T> for non-error termination conditions
like cancellation, eviction, continue-as-new, or actual failures.
Variants
Cancelled
The workflow was cancelled.
Evicted
The workflow was evicted from the cache.
ContinueAsNew(Box<ContinueAsNewWorkflowExecution>)
The workflow should continue as a new execution.
Failed(Error)
The workflow failed with an error.
Implementations
Sourceimpl WorkflowTermination
impl WorkflowTermination
Sourcepub fn continue_as_new(can: ContinueAsNewWorkflowExecution) -> Self
pub fn continue_as_new(can: ContinueAsNewWorkflowExecution) -> Self
Construct a WorkflowTermination::ContinueAsNew
Sourcepub fn failed(err: impl Into<Error>) -> Self
pub fn failed(err: impl Into<Error>) -> Self
Construct a WorkflowTermination::Failed variant from any error.