Module error

Module error 

Shared SDK error re-exports.

Structs

ApplicationFailure
User-authored application failure metadata that can be converted into a Temporal failure.

Enums

ActivityExecutionError
Error type for activity execution outcomes.
ApplicationErrorCategory
Categorizes an ApplicationFailure to hint at how the server and tooling should treat it.
CancelExternalWorkflowError
Error returned when requesting cancellation of an external workflow fails.
ChildWorkflowExecutionError
Error returned when a child workflow execution fails.
ChildWorkflowStartError
Error returned when starting a child workflow fails.
OutgoingActivityError
A typed outbound activity error.
OutgoingError
A typed outbound error surface used before encoding to a Temporal failure proto.
OutgoingWorkflowError
A typed outbound workflow failure.
RetryState
Describes why a retry did or did not occur.
RuntimeError
Errors that can occur while creating an SDK runtime.
TimeoutType
Identifies which timeout expired.
WorkerCreateError
Errors that can occur while creating a worker.
WorkerRunError
Errors that can occur while running a worker.
WorkerValidationError
Errors encountered while validating a worker before polling begins.
WorkflowRegistrationError
Error returned when a workflow cannot be registered.
WorkflowSignalError
Error returned when signaling a workflow fails.