#[non_exhaustive]pub enum ApplicationErrorCategory {
Unspecified,
Benign,
}Expand description
Categorizes an ApplicationFailure to hint at how the server and tooling should treat it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
No category was specified.
Benign
An expected error with little or no severity. Benign errors are logged at a reduced level and excluded from error metrics by the server.