InterceptorWithNext

Struct InterceptorWithNext 

pub struct InterceptorWithNext { /* private fields */ }
Supports the composition of interceptors

Implementations

Source

impl InterceptorWithNext

pub fn new(inner: Box<dyn WorkerInterceptor>) -> Self

Create from an existing interceptor, can be used to initialize a chain of interceptors

pub fn set_next( &mut self, next: Box<dyn WorkerInterceptor>, ) -> &mut InterceptorWithNext

Sets the next interceptor, and then returns that interceptor, wrapped by InterceptorWithNext. You can keep calling this method on it to extend the chain.