Module plugins

Module plugins 

Experimental APIs for configuring clients and workers with reusable plugins. Experimental plugin APIs for configuring workers and clients from reusable values.

Modules

simple_plugin_builder
Tools for manipulating the type state of SimplePluginBuilder.

Structs

ClientAndWorkerPlugin
A container for a plugin that implements both ClientPlugin and WorkerPlugin.
SimplePlugin
A plugin assembled from declarative values or functions of existing values.
SimplePluginBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowDefinitions
Contains workflow registrations in a form ready for execution by workers.

Enums

SimplePluginOption
A simple plugin field that either supplies a value or customizes the existing value.

Traits

WorkerPlugin
Configures worker options before the worker is created.