Module simple_plugin_builder

Module simple_plugin_builder 

Tools for manipulating the type state of SimplePluginBuilder.

See the detailed guide that describes how all the pieces here fit together.

Structs

Empty
Represents a State that has IsUnset implemented for all members.
SetActivities
Represents a State that has IsSet implemented for State::Activities.
SetActivityInboundInterceptors
Represents a State that has IsSet implemented for State::ActivityInboundInterceptors.
SetClientInterceptors
Represents a State that has IsSet implemented for State::ClientInterceptors.
SetDataConverter
Represents a State that has IsSet implemented for State::DataConverter.
SetWorkerInterceptors
Represents a State that has IsSet implemented for State::WorkerInterceptors.
SetWorkflowInterceptors
Represents a State that has IsSet implemented for State::WorkflowInterceptors.
SetWorkflows
Represents a State that has IsSet implemented for State::Workflows.

Traits

IsComplete
Marker trait that indicates that all required members are set.
IsSet
Marker trait that indicates that the member is set, i.e. at least one of its setters was called.
IsUnset
Marker trait that indicates that the member is unset, i.e. none of its setters was called.
State
Builder’s type state specifies if members are set or not (unset).