pub trait IsComplete: State { }Available on crate feature
experimental only.Expand description
Marker trait that indicates that all required members are set.
In this state, you can finish building by calling the method SimplePluginBuilder::build()
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".