State

Trait State 

pub trait State: Sized {
    type DataConverter;
    type ClientInterceptors;
    type WorkerInterceptors;
    type ActivityInboundInterceptors;
    type WorkflowInterceptors;
    type Activities;
    type Workflows;
}
Builder’s type state specifies if members are set or not (unset).

You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.

Required Associated Types

type DataConverter

Type state of the member data_converter.

It can implement either IsSet or IsUnset

type ClientInterceptors

Type state of the member client_interceptors.

It can implement either IsSet or IsUnset

type WorkerInterceptors

Type state of the member worker_interceptors.

It can implement either IsSet or IsUnset

type ActivityInboundInterceptors

Type state of the member activity_inbound_interceptors.

It can implement either IsSet or IsUnset

type WorkflowInterceptors

Type state of the member workflow_interceptors.

It can implement either IsSet or IsUnset

type Activities

Type state of the member activities.

It can implement either IsSet or IsUnset

type Workflows

Type state of the member workflows.

It can implement either IsSet or IsUnset

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors