pub struct ResourceBasedTuner<MI> { /* private fields */ }Expand description
Implements crate::worker::WorkerTuner and attempts to maintain certain levels of resource usage when under load.
It does so by using two PID controllers, one for memory and one for CPU, which are fed the current usage levels of their respective resource as measurements. The user specifies a target threshold for each, and slots are handed out if the output of both PID controllers is above some defined threshold. See ResourceBasedSlotsOptions for the default PID controller settings.
Note that different slot types make decisions independently of each other, though they use the same underlying system information.
Implementations
Sourceimpl ResourceBasedTuner<RealSysInfo>
impl ResourceBasedTuner<RealSysInfo>
Sourcepub fn new(
target_mem_usage: f64,
target_cpu_usage: f64,
) -> ResourceBasedTuner<RealSysInfo>
pub fn new( target_mem_usage: f64, target_cpu_usage: f64, ) -> ResourceBasedTuner<RealSysInfo>
Create an instance attempting to target the provided memory and cpu thresholds as values between 0 and 1.
Sourcepub fn new_from_options(
options: ResourceBasedSlotsOptions,
) -> ResourceBasedTuner<RealSysInfo>
pub fn new_from_options( options: ResourceBasedSlotsOptions, ) -> ResourceBasedTuner<RealSysInfo>
Create an instance using the fully configurable set of PID controller options
Sourceimpl<MI> ResourceBasedTuner<MI>
impl<MI> ResourceBasedTuner<MI>
Sourcepub fn with_workflow_slots_options(
&mut self,
opts: ResourceSlotOptions,
) -> &mut ResourceBasedTuner<MI>
pub fn with_workflow_slots_options( &mut self, opts: ResourceSlotOptions, ) -> &mut ResourceBasedTuner<MI>
Set workflow slot options
Sourcepub fn with_activity_slots_options(
&mut self,
opts: ResourceSlotOptions,
) -> &mut ResourceBasedTuner<MI>
pub fn with_activity_slots_options( &mut self, opts: ResourceSlotOptions, ) -> &mut ResourceBasedTuner<MI>
Set activity slot options
Sourcepub fn with_local_activity_slots_options(
&mut self,
opts: ResourceSlotOptions,
) -> &mut ResourceBasedTuner<MI>
pub fn with_local_activity_slots_options( &mut self, opts: ResourceSlotOptions, ) -> &mut ResourceBasedTuner<MI>
Set local activity slot options
Sourcepub fn with_nexus_slots_options(
&mut self,
opts: ResourceSlotOptions,
) -> &mut ResourceBasedTuner<MI>
pub fn with_nexus_slots_options( &mut self, opts: ResourceSlotOptions, ) -> &mut ResourceBasedTuner<MI>
Set nexus slot options