pub struct Runtime(/* private fields */);Expand description
Holds shared state and components used by Rust SDK workers.
Implementations
Sourceimpl Runtime
impl Runtime
Sourcepub fn new(
options: RuntimeOptions,
tokio_builder: TokioRuntimeBuilder,
) -> Result<Self, RuntimeError>
pub fn new( options: RuntimeOptions, tokio_builder: TokioRuntimeBuilder, ) -> Result<Self, RuntimeError>
Creates a runtime with a newly constructed Tokio runtime.
Errors
Returns an error if telemetry or the Tokio runtime cannot be initialized.
Sourcepub fn from_current_tokio(options: RuntimeOptions) -> Result<Self, RuntimeError>
pub fn from_current_tokio(options: RuntimeOptions) -> Result<Self, RuntimeError>
Creates a runtime using the currently active Tokio runtime.
Errors
Returns RuntimeError::NoCurrentTokioRuntime if there is no currently active Tokio
runtime, or RuntimeError::Initialization if telemetry cannot be initialized.
Sourcepub fn new_assume_tokio(options: RuntimeOptions) -> Result<Self, RuntimeError>
👎Deprecated: use Runtime::from_current_tokio instead
pub fn new_assume_tokio(options: RuntimeOptions) -> Result<Self, RuntimeError>
use Runtime::from_current_tokio instead
Creates a runtime using the currently active Tokio runtime.
Errors
Returns RuntimeError::NoCurrentTokioRuntime if there is no currently active Tokio
runtime, or RuntimeError::Initialization if telemetry cannot be initialized.