SlotSupplierPermit

Struct SlotSupplierPermit 

pub struct SlotSupplierPermit { /* private fields */ }
A permit issued by a SlotSupplier.

Implementations

Source

impl SlotSupplierPermit

pub fn with_user_data<T>(user_data: T) -> SlotSupplierPermit
where T: Any + Send + Sync,

Attach some user data to the slot permit.

pub fn user_data<T>(&self) -> Option<&T>
where T: Any + Send + Sync,

Attempts to downcast the inner data, if any, into the provided type and returns it. Returns none if there is no data or the data is not of the appropriate type.

pub fn user_data_mut<T>(&mut self) -> Option<&mut T>
where T: Any + Send + Sync,

Attempts to downcast the inner data, if any, into the provided type and returns it mutably. Returns none if there is no data or the data is not of the appropriate type.