IsComplete

pub trait IsComplete: State<Inner: IsSet> { }
Marker trait that indicates that all required members are set.

In this state, you can finish building by calling the method TokioRuntimeBuilderBuilder::build()

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors