SlotReservationContext

Trait SlotReservationContext 

pub trait SlotReservationContext: Send + Sync {
    // Required methods
    fn task_queue(&self) -> &str;
    fn worker_identity(&self) -> &str;
    fn worker_deployment_version(&self) -> &Option<WorkerDeploymentVersion>;
    fn num_issued_slots(&self) -> usize;
    fn is_sticky(&self) -> bool;

    // Provided method
    fn get_metrics_meter(&self) -> Option<TemporalMeter> { ... }
}
Context for slot reservation.

Required Methods

fn task_queue(&self) -> &str

Returns the name of the task queue this worker is polling

fn worker_identity(&self) -> &str

Returns the identity of the worker

fn worker_deployment_version(&self) -> &Option<WorkerDeploymentVersion>

Returns the deployment version of the worker, if one is set.

fn num_issued_slots(&self) -> usize

Returns the number of currently outstanding slot permits, whether used or un-used.

fn is_sticky(&self) -> bool

Returns true iff this is a sticky poll for a workflow task

Provided Methods

fn get_metrics_meter(&self) -> Option<TemporalMeter>

Returns the metrics meter if metrics are enabled

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors