#[non_exhaustive]pub struct ResourceBasedSlotOptions {
pub minimum_slots: Option<usize>,
pub maximum_slots: Option<usize>,
pub ramp_throttle: Option<Duration>,
}Expand description
Per-task-type options for resource-based slots.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.minimum_slots: Option<usize>Slots issued without consulting resource usage, or None to use the task-type default.
maximum_slots: Option<usize>Maximum slots that may be issued, or None to use the task-type default.
ramp_throttle: Option<Duration>Minimum delay between slots above the minimum, or None to use the task-type default.
Implementations
Sourceimpl ResourceBasedSlotOptions
impl ResourceBasedSlotOptions
Sourcepub fn builder() -> ResourceBasedSlotOptionsBuilder
pub fn builder() -> ResourceBasedSlotOptionsBuilder
Create an instance of ResourceBasedSlotOptions using the builder syntax