#[non_exhaustive]pub struct ResourceBasedTunerOptions {
pub target_memory_usage: f64,
pub target_cpu_usage: f64,
}Expand description
Target resource usage for resource-based tuning.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_memory_usage: f64Target system memory usage as a fraction from zero to one.
target_cpu_usage: f64Target system CPU usage as a fraction from zero to one.
Implementations
Sourceimpl ResourceBasedTunerOptions
impl ResourceBasedTunerOptions
Sourcepub fn builder() -> ResourceBasedTunerOptionsBuilder
pub fn builder() -> ResourceBasedTunerOptionsBuilder
Create an instance of ResourceBasedTunerOptions using the builder syntax