pub struct ResourceBasedTunerOptionsBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ResourceBasedTunerOptionsBuilder<S>
impl<S: State> ResourceBasedTunerOptionsBuilder<S>
Sourcepub fn build(self) -> ResourceBasedTunerOptionswhere
S: IsComplete,
pub fn build(self) -> ResourceBasedTunerOptionswhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn target_memory_usage(
self,
value: f64,
) -> ResourceBasedTunerOptionsBuilder<SetTargetMemoryUsage<S>>where
S::TargetMemoryUsage: IsUnset,
pub fn target_memory_usage(
self,
value: f64,
) -> ResourceBasedTunerOptionsBuilder<SetTargetMemoryUsage<S>>where
S::TargetMemoryUsage: IsUnset,
Required.
Target system memory usage as a fraction from zero to one.
Sourcepub fn target_cpu_usage(
self,
value: f64,
) -> ResourceBasedTunerOptionsBuilder<SetTargetCpuUsage<S>>where
S::TargetCpuUsage: IsUnset,
pub fn target_cpu_usage(
self,
value: f64,
) -> ResourceBasedTunerOptionsBuilder<SetTargetCpuUsage<S>>where
S::TargetCpuUsage: IsUnset,
Required.
Target system CPU usage as a fraction from zero to one.