pub struct BaseWorkflowContext { /* private fields */ }Expand description
Non-generic base context containing all workflow execution infrastructure.
This is used internally by futures and commands that don’t need typed workflow state.
Implementations
Sourceimpl BaseWorkflowContext
impl BaseWorkflowContext
Sourcepub fn data_converter(&self) -> &DataConverter
pub fn data_converter(&self) -> &DataConverter
Returns the DataConverter associated with this workflow’s worker.
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
Return the workflow’s unique identifier.
Sourcepub fn task_queue(&self) -> &str
pub fn task_queue(&self) -> &str
Return the task queue the workflow is executing in.
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
Return the workflow type name.
Sourcepub fn workflow_time(&self) -> Option<SystemTime>
pub fn workflow_time(&self) -> Option<SystemTime>
Return the current time according to the workflow.
Sourcepub fn history_length(&self) -> u32
pub fn history_length(&self) -> u32
Return the length of history so far at this point in the workflow.
Sourcepub fn search_attributes(&self) -> SearchAttributes
pub fn search_attributes(&self) -> SearchAttributes
Return current values for workflow search attributes.
Sourcepub fn is_replaying(&self) -> bool
pub fn is_replaying(&self) -> bool
Returns true if the workflow is replaying (including during queries and update validators), false otherwise.
Sourcepub fn is_replaying_history_events(&self) -> bool
pub fn is_replaying_history_events(&self) -> bool
Return true if the workflow is replaying history events (excluding queries and update validators), false otherwise.
Sourcepub fn payload_converter(&self) -> &PayloadConverter
pub fn payload_converter(&self) -> &PayloadConverter
Returns the payload converter used by the worker running this workflow.
Sourceimpl BaseWorkflowContext
impl BaseWorkflowContext
Sourcepub fn current_details(&self) -> String
pub fn current_details(&self) -> String
Return the current value of current_details.
Sourcepub fn timer<T>(&self, opts: T) -> impl CancellableFuture<TimerResult> + use<T>where
T: Into<TimerOptions>,
pub fn timer<T>(&self, opts: T) -> impl CancellableFuture<TimerResult> + use<T>where
T: Into<TimerOptions>,
Request to create a timer
Sourcepub fn execute_activity<AD>(
&self,
activity: AD,
input: impl Into<<AD as ActivityDefinition>::Input>,
opts: ActivityOptions,
) -> impl CancellableFuture<Result<<AD as ActivityDefinition>::Output, ActivityExecutionError>>
pub fn execute_activity<AD>( &self, activity: AD, input: impl Into<<AD as ActivityDefinition>::Input>, opts: ActivityOptions, ) -> impl CancellableFuture<Result<<AD as ActivityDefinition>::Output, ActivityExecutionError>>
Request to run an activity
Sourcepub fn execute_local_activity<AD>(
&self,
activity: AD,
input: impl Into<<AD as ActivityDefinition>::Input>,
opts: LocalActivityOptions,
) -> impl CancellableFuture<Result<<AD as ActivityDefinition>::Output, ActivityExecutionError>>
pub fn execute_local_activity<AD>( &self, activity: AD, input: impl Into<<AD as ActivityDefinition>::Input>, opts: LocalActivityOptions, ) -> impl CancellableFuture<Result<<AD as ActivityDefinition>::Output, ActivityExecutionError>>
Request to run a local activity