ChildWorkflowOptions

Struct ChildWorkflowOptions 

pub struct ChildWorkflowOptions {
Show 15 fields pub workflow_id: String, pub workflow_type: String, pub task_queue: Option<String>, pub input: Vec<Payload>, pub cancel_type: ChildWorkflowCancellationType, pub parent_close_policy: ParentClosePolicy, pub static_summary: Option<String>, pub static_details: Option<String>, pub id_reuse_policy: WorkflowIdReusePolicy, pub execution_timeout: Option<Duration>, pub run_timeout: Option<Duration>, pub task_timeout: Option<Duration>, pub cron_schedule: Option<String>, pub search_attributes: Option<HashMap<String, Payload>>, pub priority: Option<Priority>,
}
Options for scheduling a child workflow

Fields

workflow_id: String

Workflow ID

workflow_type: String

Type of workflow to schedule

task_queue: Option<String>

Task queue to schedule the workflow in

If None, use the same task queue as the parent workflow.

input: Vec<Payload>

Input to send the child Workflow

cancel_type: ChildWorkflowCancellationType

Cancellation strategy for the child workflow

parent_close_policy: ParentClosePolicy

How to respond to parent workflow ending

static_summary: Option<String>

Static summary of the child workflow

static_details: Option<String>

Static details of the child workflow

id_reuse_policy: WorkflowIdReusePolicy

Set the policy for reusing the workflow id

execution_timeout: Option<Duration>

Optionally set the execution timeout for the workflow

run_timeout: Option<Duration>

Optionally indicates the default run timeout for a workflow run

task_timeout: Option<Duration>

Optionally indicates the default task timeout for a workflow run

cron_schedule: Option<String>

Optionally set a cron schedule for the workflow

search_attributes: Option<HashMap<String, Payload>>

Optionally associate extra search attributes with a workflow

priority: Option<Priority>

Priority for the workflow