LocalActivityOptions

Struct LocalActivityOptions 

pub struct LocalActivityOptions {
    pub activity_id: Option<String>,
    pub retry_policy: RetryPolicy,
    pub attempt: Option<u32>,
    pub original_schedule_time: Option<Timestamp>,
    pub timer_backoff_threshold: Option<Duration>,
    pub cancel_type: ActivityCancellationType,
    pub schedule_to_close_timeout: Option<Duration>,
    pub schedule_to_start_timeout: Option<Duration>,
    pub start_to_close_timeout: Option<Duration>,
    pub summary: Option<String>,
}
Options for scheduling a local activity

Fields

activity_id: Option<String>

Identifier to use for tracking the activity in Workflow history. The activityId can be accessed by the activity function. Does not need to be unique.

If None use the context’s sequence number

retry_policy: RetryPolicy

Retry policy

attempt: Option<u32>

Override attempt number rather than using 1. Ideally we would not expose this in a released Rust SDK, but it’s needed for test.

original_schedule_time: Option<Timestamp>

Override schedule time when doing timer backoff. Ideally we would not expose this in a released Rust SDK, but it’s needed for test.

timer_backoff_threshold: Option<Duration>

Retry backoffs over this amount will use a timer rather than a local retry

cancel_type: ActivityCancellationType

How the activity will cancel

schedule_to_close_timeout: Option<Duration>

Indicates how long the caller is willing to wait for local activity completion. Limits how long retries will be attempted. When not specified defaults to the workflow execution timeout (which may be unset).

schedule_to_start_timeout: Option<Duration>

Limits time the local activity can idle internally before being executed. That can happen if the worker is currently at max concurrent local activity executions. This timeout is always non retryable as all a retry would achieve is to put it back into the same queue. Defaults to schedule_to_close_timeout if not specified and that is set. Must be <= schedule_to_close_timeout when set, if not, it will be clamped down.

start_to_close_timeout: Option<Duration>

Maximum time the local activity is allowed to execute after the task is dispatched. This timeout is always retryable. Either or both of schedule_to_close_timeout and this must be specified. If set, this must be <= schedule_to_close_timeout, if not, it will be clamped down.

summary: Option<String>

Single-line summary for this activity that will appear in UI/CLI.