PendingChildWorkflow

Struct PendingChildWorkflow 

pub struct PendingChildWorkflow {
    pub status: Status,
    /* private fields */
}
Child workflow in pending state

Fields

status: Status

The status of the child workflow start

Implementations

Source

impl PendingChildWorkflow

pub fn into_started(self) -> Option<StartedChildWorkflow>

Returns None if the child did not start successfully. The returned StartedChildWorkflow can be used to wait on, signal, or cancel the child workflow.