pub struct SignalWorkflowOptions {
pub workflow_id: String,
pub run_id: Option<String>,
pub signal: Signal,
}Expand description
Options for sending a signal to an external workflow
Fields
workflow_id: StringThe workflow’s id
run_id: Option<String>The particular run to target, or latest if None
signal: SignalThe details of the signal to send
Implementations