Worker

Struct Worker 

pub struct Worker { /* private fields */ }
A worker that can poll for and respond to workflow tasks by using temporalio_macros::workflow, and activity tasks by using activities defined with temporalio_macros::activities.

Implementations

Source

impl Worker

pub fn new( runtime: &CoreRuntime, client: Client, options: WorkerOptions, ) -> Result<Self, Box<dyn Error>>

Create a new worker from an existing connection, and options.

pub fn task_queue(&self) -> &str

Returns the task queue name this worker polls on

pub fn shutdown_handle(&self) -> impl Fn() + use<>

Return a handle that can be used to initiate shutdown. This is useful because Worker::run takes self mutably, so you may want to obtain a handle for shutting down before running.

pub fn register_activities<AI: ActivityImplementer>( &mut self, instance: AI, ) -> &mut Self

Registers all activities on an activity implementer.

pub fn register_activity<AD>( &mut self, instance: Arc<AD::Implementer>, ) -> &mut Self
where AD: ActivityDefinition + ExecutableActivity, AD::Output: Send + Sync,

Registers a specific activitiy.

pub fn register_workflow<WI: WorkflowImplementer>(&mut self) -> &mut Self

Registers all workflows on a workflow implementer.

pub fn register_workflow_with_factory<W, F>(&mut self, factory: F) -> &mut Self
where W: WorkflowImplementation, <W::Run as WorkflowDefinition>::Input: Send, F: Fn() -> W + Send + Sync + 'static,

Register a workflow with a custom factory for instance creation.

See WorkerOptionsBuilder::register_workflow_with_factory for more.

pub async fn run(&mut self) -> Result<(), Error>

Runs the worker. Eventually resolves after the worker has been explicitly shut down, or may return early with an error in the event of some unresolvable problem.

pub fn set_worker_interceptor( &mut self, interceptor: impl WorkerInterceptor + 'static, )

pub fn with_new_core_worker(&mut self, new_core_worker: Arc<CoreWorker>)

Turns this rust worker into a new worker with all the same workflows and activities registered, but with a new underlying core worker. Can be used to swap the worker for a replay worker, change task queues, etc.

pub fn cached_workflows(&self) -> usize

Returns number of currently cached workflows as understood by the SDK. Importantly, this is not the same as understood by core, though they should always be in sync.

pub fn worker_instance_key(&self) -> Uuid

Returns the instance key for this worker, used for worker heartbeating.