WorkerOptionsBuilder

Struct WorkerOptionsBuilder 

pub struct WorkerOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> WorkerOptionsBuilder<S>

pub fn build(self) -> WorkerOptions
where S: IsComplete,

Finish building and return the requested object

pub fn deployment_options( self, value: WorkerDeploymentOptions, ) -> WorkerOptionsBuilder<SetDeploymentOptions<S>>

Optional (Some / Option setters). Default: def_build_id().

Set the deployment options for this worker. Defaults to a hash of the currently running executable.

pub fn maybe_deployment_options( self, value: Option<WorkerDeploymentOptions>, ) -> WorkerOptionsBuilder<SetDeploymentOptions<S>>

Optional (Some / Option setters). Default: def_build_id().

Set the deployment options for this worker. Defaults to a hash of the currently running executable.

pub fn client_identity_override( self, value: impl Into<String>, ) -> WorkerOptionsBuilder<SetClientIdentityOverride<S>>

Optional (Some / Option setters).

A human-readable string that can identify this worker. Using something like sdk version and host name is a good default. If set, overrides the identity set (if any) on the client used by this worker.

pub fn maybe_client_identity_override( self, value: Option<impl Into<String>>, ) -> WorkerOptionsBuilder<SetClientIdentityOverride<S>>

Optional (Some / Option setters).

A human-readable string that can identify this worker. Using something like sdk version and host name is a good default. If set, overrides the identity set (if any) on the client used by this worker.

pub fn max_cached_workflows( self, value: usize, ) -> WorkerOptionsBuilder<SetMaxCachedWorkflows<S>>

Optional (Some / Option setters). Default: 1000.

If set nonzero, workflows will be cached and sticky task queues will be used, meaning that history updates are applied incrementally to suspended instances of workflow execution. Workflows are evicted according to a least-recently-used policy once the cache maximum is reached. Workflows may also be explicitly evicted at any time, or as a result of errors or failures.

pub fn maybe_max_cached_workflows( self, value: Option<usize>, ) -> WorkerOptionsBuilder<SetMaxCachedWorkflows<S>>

Optional (Some / Option setters). Default: 1000.

If set nonzero, workflows will be cached and sticky task queues will be used, meaning that history updates are applied incrementally to suspended instances of workflow execution. Workflows are evicted according to a least-recently-used policy once the cache maximum is reached. Workflows may also be explicitly evicted at any time, or as a result of errors or failures.

pub fn tuner( self, value: Arc<dyn WorkerTuner + Send + Sync>, ) -> WorkerOptionsBuilder<SetTuner<S>>
where S::Tuner: IsUnset,

Optional (Some / Option setters). Default: Arc::new(TunerBuilder::default().build()).

Set a crate::WorkerTuner for this worker, which controls how many slots are available for the different kinds of tasks.

pub fn maybe_tuner( self, value: Option<Arc<dyn WorkerTuner + Send + Sync>>, ) -> WorkerOptionsBuilder<SetTuner<S>>
where S::Tuner: IsUnset,

Optional (Some / Option setters). Default: Arc::new(TunerBuilder::default().build()).

Set a crate::WorkerTuner for this worker, which controls how many slots are available for the different kinds of tasks.

pub fn workflow_task_poller_behavior( self, value: PollerBehavior, ) -> WorkerOptionsBuilder<SetWorkflowTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Workflow tasks will happen on this worker’s task queue. See also WorkerConfig::nonsticky_to_sticky_poll_ratio. If using SimpleMaximum, Must be at least 2 when max_cached_workflows > 0, or is an error.

pub fn maybe_workflow_task_poller_behavior( self, value: Option<PollerBehavior>, ) -> WorkerOptionsBuilder<SetWorkflowTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Workflow tasks will happen on this worker’s task queue. See also WorkerConfig::nonsticky_to_sticky_poll_ratio. If using SimpleMaximum, Must be at least 2 when max_cached_workflows > 0, or is an error.

pub fn nonsticky_to_sticky_poll_ratio( self, value: f32, ) -> WorkerOptionsBuilder<SetNonstickyToStickyPollRatio<S>>

Optional (Some / Option setters). Default: 0.2.

Only applies when using PollerBehavior::SimpleMaximum

(max workflow task polls * this number) = the number of max pollers that will be allowed for the nonsticky queue when sticky tasks are enabled. If both defaults are used, the sticky queue will allow 4 max pollers while the nonsticky queue will allow one. The minimum for either poller is 1, so if the maximum allowed is 1 and sticky queues are enabled, there will be 2 concurrent polls.

pub fn maybe_nonsticky_to_sticky_poll_ratio( self, value: Option<f32>, ) -> WorkerOptionsBuilder<SetNonstickyToStickyPollRatio<S>>

Optional (Some / Option setters). Default: 0.2.

Only applies when using PollerBehavior::SimpleMaximum

(max workflow task polls * this number) = the number of max pollers that will be allowed for the nonsticky queue when sticky tasks are enabled. If both defaults are used, the sticky queue will allow 4 max pollers while the nonsticky queue will allow one. The minimum for either poller is 1, so if the maximum allowed is 1 and sticky queues are enabled, there will be 2 concurrent polls.

pub fn activity_task_poller_behavior( self, value: PollerBehavior, ) -> WorkerOptionsBuilder<SetActivityTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Activity tasks will happen on this worker’s task queue.

pub fn maybe_activity_task_poller_behavior( self, value: Option<PollerBehavior>, ) -> WorkerOptionsBuilder<SetActivityTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Activity tasks will happen on this worker’s task queue.

pub fn nexus_task_poller_behavior( self, value: PollerBehavior, ) -> WorkerOptionsBuilder<SetNexusTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Nexus tasks will happen on this worker’s task queue.

pub fn maybe_nexus_task_poller_behavior( self, value: Option<PollerBehavior>, ) -> WorkerOptionsBuilder<SetNexusTaskPollerBehavior<S>>

Optional (Some / Option setters). Default: PollerBehavior::SimpleMaximum(5).

Controls how polling for Nexus tasks will happen on this worker’s task queue.

pub fn task_types( self, value: WorkerTaskTypes, ) -> WorkerOptionsBuilder<SetTaskTypes<S>>
where S::TaskTypes: IsUnset,

Optional (Some / Option setters). Default: WorkerTaskTypes::all().

Specifies which task types this worker will poll for.

Note: At least one task type must be specified or the worker will fail validation.

pub fn maybe_task_types( self, value: Option<WorkerTaskTypes>, ) -> WorkerOptionsBuilder<SetTaskTypes<S>>
where S::TaskTypes: IsUnset,

Optional (Some / Option setters). Default: WorkerTaskTypes::all().

Specifies which task types this worker will poll for.

Note: At least one task type must be specified or the worker will fail validation.

pub fn sticky_queue_schedule_to_start_timeout( self, value: Duration, ) -> WorkerOptionsBuilder<SetStickyQueueScheduleToStartTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(10).

How long a workflow task is allowed to sit on the sticky queue before it is timed out and moved to the non-sticky queue where it may be picked up by any worker.

pub fn maybe_sticky_queue_schedule_to_start_timeout( self, value: Option<Duration>, ) -> WorkerOptionsBuilder<SetStickyQueueScheduleToStartTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(10).

How long a workflow task is allowed to sit on the sticky queue before it is timed out and moved to the non-sticky queue where it may be picked up by any worker.

pub fn max_heartbeat_throttle_interval( self, value: Duration, ) -> WorkerOptionsBuilder<SetMaxHeartbeatThrottleInterval<S>>

Optional (Some / Option setters). Default: Duration::from_secs(60).

Longest interval for throttling activity heartbeats

pub fn maybe_max_heartbeat_throttle_interval( self, value: Option<Duration>, ) -> WorkerOptionsBuilder<SetMaxHeartbeatThrottleInterval<S>>

Optional (Some / Option setters). Default: Duration::from_secs(60).

Longest interval for throttling activity heartbeats

pub fn default_heartbeat_throttle_interval( self, value: Duration, ) -> WorkerOptionsBuilder<SetDefaultHeartbeatThrottleInterval<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

Default interval for throttling activity heartbeats in case ActivityOptions.heartbeat_timeout is unset. When the timeout is set in the ActivityOptions, throttling is set to heartbeat_timeout * 0.8.

pub fn maybe_default_heartbeat_throttle_interval( self, value: Option<Duration>, ) -> WorkerOptionsBuilder<SetDefaultHeartbeatThrottleInterval<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

Default interval for throttling activity heartbeats in case ActivityOptions.heartbeat_timeout is unset. When the timeout is set in the ActivityOptions, throttling is set to heartbeat_timeout * 0.8.

pub fn max_task_queue_activities_per_second( self, value: f64, ) -> WorkerOptionsBuilder<SetMaxTaskQueueActivitiesPerSecond<S>>

Optional (Some / Option setters).

Sets the maximum number of activities per second the task queue will dispatch, controlled server-side. Note that this only takes effect upon an activity poll request. If multiple workers on the same queue have different values set, they will thrash with the last poller winning.

Setting this to a nonzero value will also disable eager activity execution.

pub fn maybe_max_task_queue_activities_per_second( self, value: Option<f64>, ) -> WorkerOptionsBuilder<SetMaxTaskQueueActivitiesPerSecond<S>>

Optional (Some / Option setters).

Sets the maximum number of activities per second the task queue will dispatch, controlled server-side. Note that this only takes effect upon an activity poll request. If multiple workers on the same queue have different values set, they will thrash with the last poller winning.

Setting this to a nonzero value will also disable eager activity execution.

pub fn max_worker_activities_per_second( self, value: f64, ) -> WorkerOptionsBuilder<SetMaxWorkerActivitiesPerSecond<S>>

Optional (Some / Option setters).

Limits the number of activities per second that this worker will process. The worker will not poll for new activities if by doing so it might receive and execute an activity which would cause it to exceed this limit. Negative, zero, or NaN values will cause building the options to fail.

pub fn maybe_max_worker_activities_per_second( self, value: Option<f64>, ) -> WorkerOptionsBuilder<SetMaxWorkerActivitiesPerSecond<S>>

Optional (Some / Option setters).

Limits the number of activities per second that this worker will process. The worker will not poll for new activities if by doing so it might receive and execute an activity which would cause it to exceed this limit. Negative, zero, or NaN values will cause building the options to fail.

pub fn workflow_failure_errors( self, value: HashSet<WorkflowErrorType>, ) -> WorkerOptionsBuilder<SetWorkflowFailureErrors<S>>

Optional (Some / Option setters). Default: <HashSet<WorkflowErrorType> as Default>::default().

Any error types listed here will cause any workflow being processed by this worker to fail, rather than simply failing the workflow task.

pub fn maybe_workflow_failure_errors( self, value: Option<HashSet<WorkflowErrorType>>, ) -> WorkerOptionsBuilder<SetWorkflowFailureErrors<S>>

Optional (Some / Option setters). Default: <HashSet<WorkflowErrorType> as Default>::default().

Any error types listed here will cause any workflow being processed by this worker to fail, rather than simply failing the workflow task.

pub fn workflow_types_to_failure_errors( self, value: HashMap<String, HashSet<WorkflowErrorType>>, ) -> WorkerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>

Optional (Some / Option setters). Default: <HashMap<String, HashSet<WorkflowErrorType>> as Default>::default().

Like WorkerConfig::workflow_failure_errors, but specific to certain workflow types (the map key).

pub fn maybe_workflow_types_to_failure_errors( self, value: Option<HashMap<String, HashSet<WorkflowErrorType>>>, ) -> WorkerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>

Optional (Some / Option setters). Default: <HashMap<String, HashSet<WorkflowErrorType>> as Default>::default().

Like WorkerConfig::workflow_failure_errors, but specific to certain workflow types (the map key).

pub fn graceful_shutdown_period( self, value: Duration, ) -> WorkerOptionsBuilder<SetGracefulShutdownPeriod<S>>

Optional (Some / Option setters).

If set, the worker will issue cancels for all outstanding activities and nexus operations after shutdown has been initiated and this amount of time has elapsed.

pub fn maybe_graceful_shutdown_period( self, value: Option<Duration>, ) -> WorkerOptionsBuilder<SetGracefulShutdownPeriod<S>>

Optional (Some / Option setters).

If set, the worker will issue cancels for all outstanding activities and nexus operations after shutdown has been initiated and this amount of time has elapsed.

Source

impl<S: State> WorkerOptionsBuilder<S>

pub fn register_activities<AI: ActivityImplementer>(self, instance: AI) -> Self

Registers all activities on an activity implementer.

pub fn register_activity<AD>(self, instance: Arc<AD::Implementer>) -> Self
where AD: ActivityDefinition + ExecutableActivity, AD::Output: Send + Sync,

Registers a specific activitiy.

pub fn register_workflow<WI: WorkflowImplementer>(self) -> Self

Registers all workflows on a workflow implementer.

pub fn register_workflow_with_factory<W, F>(self, factory: F) -> Self
where W: WorkflowImplementation, <W::Run as WorkflowDefinition>::Input: Send, F: Fn() -> W + Send + Sync + 'static,

Register a workflow with a custom factory for instance creation.

Warning: Advanced Usage

This method is intended for scenarios requiring injection of un-serializable state into workflows.

This can easily cause nondeterminism

Only use when you understand the implications and have a specific need that cannot be met otherwise.

Panics

Panics if the workflow type defines an #[init] method. Workflows using factory registration must not have #[init] to avoid ambiguity about instance creation.