WorkflowContext

Struct WorkflowContext 

pub struct WorkflowContext<W> { /* private fields */ }
Used within workflows to issue commands, get info, etc.

The type parameter W represents the workflow type. This enables type-safe access to workflow state via state_mut() for mutations.

Implementations

Source

impl<W> WorkflowContext<W>

pub fn namespace(&self) -> &str

Return the namespace the workflow is executing in

pub fn task_queue(&self) -> &str

Return the task queue the workflow is executing in

pub fn workflow_time(&self) -> Option<SystemTime>

Return the current time according to the workflow (which is not wall-clock time).

pub fn history_length(&self) -> u32

Return the length of history so far at this point in the workflow

pub fn current_deployment_version(&self) -> Option<WorkerDeploymentVersion>

Return the deployment version, if any, as it was when this point in the workflow was first reached. If this code is being executed for the first time, return this Worker’s deployment version if it has one.

pub fn search_attributes(&self) -> impl Deref<Target = SearchAttributes> + '_

Return current values for workflow search attributes

pub fn random_seed(&self) -> u64

Return the workflow’s randomness seed

pub fn is_replaying(&self) -> bool

Returns true if the current workflow task is happening under replay

pub fn headers(&self) -> &HashMap<String, Payload>

Returns the headers for the current handler invocation (signal, update, query, etc.).

pub fn payload_converter(&self) -> &PayloadConverter

Returns the PayloadConverter currently used by the worker running this workflow.

pub fn workflow_initial_info(&self) -> &InitializeWorkflow

Return various information that the workflow was initialized with.

pub async fn cancelled(&self) -> String

A future that resolves if/when the workflow is cancelled, with the user provided cause

pub fn timer<T: Into<TimerOptions>>( &self, opts: T, ) -> impl CancellableFuture<TimerResult>

Request to create a timer

pub fn start_activity<AD: ActivityDefinition>( &self, activity: AD, input: impl Into<AD::Input>, opts: ActivityOptions, ) -> impl CancellableFuture<Result<AD::Output, ActivityExecutionError>>

Request to run an activity

pub fn start_local_activity<AD: ActivityDefinition>( &self, activity: AD, input: impl Into<AD::Input>, opts: LocalActivityOptions, ) -> impl CancellableFuture<Result<AD::Output, ActivityExecutionError>>

Request to run a local activity

pub fn child_workflow(&self, opts: ChildWorkflowOptions) -> ChildWorkflow

Creates a child workflow stub with the provided options

pub fn patched(&self, patch_id: &str) -> bool

Check (or record) that this workflow history was created with the provided patch

pub fn deprecate_patch(&self, patch_id: &str) -> bool

Record that this workflow history was created with the provided patch, and it is being phased out.

pub fn signal_workflow( &self, opts: impl Into<SignalWorkflowOptions>, ) -> impl CancellableFuture<SignalExternalWfResult>

Send a signal to an external workflow.

pub fn upsert_search_attributes( &self, attr_iter: impl IntoIterator<Item = (String, Payload)>, )

Add or create a set of search attributes

pub fn upsert_memo( &self, attr_iter: impl IntoIterator<Item = (String, Payload)>, )

Add or create a set of memo fields

pub fn force_task_fail(&self, with: Error)

Force a workflow task failure (EX: in order to retry on non-sticky queue)

pub fn cancel_external( &self, target: NamespacedWorkflowExecution, reason: String, ) -> impl Future<Output = CancelExternalWfResult>

Request the cancellation of an external workflow.

pub fn start_nexus_operation( &self, opts: NexusOperationOptions, ) -> impl CancellableFuture<Result<StartedNexusOperation, Failure>>

Start a nexus operation

pub fn state<R>(&self, f: impl FnOnce(&W) -> R) -> R

Access workflow state immutably via closure.

The borrow is scoped to the closure and cannot escape, preventing borrows from being held across await points.

pub fn state_mut<R>(&self, f: impl FnOnce(&mut W) -> R) -> R

Access workflow state mutably via closure.

The borrow is scoped to the closure and cannot escape, preventing borrows from being held across await points.

After the mutation, all wakers registered by pending wait_condition futures are woken so that waker-based combinators (e.g. FuturesOrdered) re-poll them on the next pass.

pub fn wait_condition<'a>( &'a self, condition: impl FnMut(&W) -> bool + 'a, ) -> impl Future<Output = ()> + 'a

Wait for some condition on workflow state to become true, yielding the workflow if not.

The condition closure receives an immutable reference to the workflow state, which is borrowed only for the duration of each poll (not across await points).