#[non_exhaustive]pub struct ContinueAsNewInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::continue_as_new.
Implementations
Sourceimpl ContinueAsNewInput
impl ContinueAsNewInput
Sourcepub fn options(&self) -> &ContinueAsNewOptions
pub fn options(&self) -> &ContinueAsNewOptions
Continue-as-new options.
Sourcepub fn options_mut(&mut self) -> &mut ContinueAsNewOptions
pub fn options_mut(&mut self) -> &mut ContinueAsNewOptions
Mutably access continue-as-new options.
Sourceimpl ContinueAsNewInput
impl ContinueAsNewInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this outbound call.