#[non_exhaustive]pub struct ExecuteWorkflowInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::execute.
The decoded input provided to workflow’s #[run] method.
Inputs consumed by #[init] are instead passed to WorkflowInterceptor::initialize_workflow.
Implementations
Sourceimpl ExecuteWorkflowInput
impl ExecuteWorkflowInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded workflow input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded workflow input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to the workflow execution.