#[non_exhaustive]pub struct HandleQueryInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::handle_query.
Implementations
Sourceimpl HandleQueryInput
impl HandleQueryInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers(&self) -> &HashMap<String, Payload>
pub fn headers(&self) -> &HashMap<String, Payload>
Headers attached to this handler invocation.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this handler invocation.