#[non_exhaustive]pub struct ScheduleActivityInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::schedule_activity.
Implementations
Sourceimpl ScheduleActivityInput
impl ScheduleActivityInput
Sourcepub fn activity_type(&self) -> &str
pub fn activity_type(&self) -> &str
Activity type.
Sourcepub fn activity_type_mut(&mut self) -> &mut String
pub fn activity_type_mut(&mut self) -> &mut String
Mutably access the activity type.
Sourcepub fn options(&self) -> &ActivityOptions
pub fn options(&self) -> &ActivityOptions
Activity options.
Sourcepub fn options_mut(&mut self) -> &mut ActivityOptions
pub fn options_mut(&mut self) -> &mut ActivityOptions
Mutably access activity options.
Sourceimpl ScheduleActivityInput
impl ScheduleActivityInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this outbound call.