#[non_exhaustive]pub struct StartChildWorkflowInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::start_child_workflow.
Implementations
Sourceimpl StartChildWorkflowInput
impl StartChildWorkflowInput
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
Workflow type.
Sourcepub fn workflow_type_mut(&mut self) -> &mut String
pub fn workflow_type_mut(&mut self) -> &mut String
Mutably access the workflow type.
Sourcepub fn options(&self) -> &ChildWorkflowOptions
pub fn options(&self) -> &ChildWorkflowOptions
Child workflow options.
Sourcepub fn options_mut(&mut self) -> &mut ChildWorkflowOptions
pub fn options_mut(&mut self) -> &mut ChildWorkflowOptions
Mutably access child workflow options.
Sourceimpl StartChildWorkflowInput
impl StartChildWorkflowInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this outbound call.