#[non_exhaustive]pub struct ValidateUpdateInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::validate_update.
Implementations
Sourceimpl ValidateUpdateInput
impl ValidateUpdateInput
Sourcepub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn input_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
pub fn input_mut<T>(&mut self) -> Option<&mut T>where
T: Any,
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this update invocation.