pub struct WorkflowInterceptorConstructor { /* private fields */ }Expand description
Creates one interceptor for each in-memory workflow instance.
The constructor receives a read-only view of the workflow’s initialization context. It may use that context to initialize interceptor state but must remain deterministic because it runs again when an evicted workflow is rebuilt.
Implementations
Sourceimpl WorkflowInterceptorConstructor
impl WorkflowInterceptorConstructor
Sourcepub fn new<F, I>(constructor: F) -> WorkflowInterceptorConstructor
pub fn new<F, I>(constructor: F) -> WorkflowInterceptorConstructor
Create a workflow interceptor constructor.