WorkflowOutputValue

Trait WorkflowOutputValue 

pub trait WorkflowOutputValue:
    Any
    + TemporalSerializable
    + Sealed {
    // Required method
    fn as_any(&self) -> &(dyn Any + 'static);
}
Type-erased workflow output carried through the workflow interceptor chain.

Required Methods

fn as_any(&self) -> &(dyn Any + 'static)

Access this value as Any for type-specific inspection.

Implementations

Source

impl dyn WorkflowOutputValue

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: Any,

Attempt to access the workflow output as a concrete type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors