#[non_exhaustive]pub enum WorkflowReplayFailure {
InvalidHistory {
message: String,
},
Nondeterminism {
message: String,
},
WorkflowTaskFailure {
message: String,
},
Internal {
reason: String,
message: String,
},
}Expand description
A failure attributable to one workflow history during replay.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidHistory
The history could not be replayed because it was malformed or incomplete.
Nondeterminism
Workflow code was incompatible with recorded history.
WorkflowTaskFailure
Language workflow execution failed while processing a task.
Internal
Replay ended for an unexpected internal reason.