pub struct WorkflowReplayer { /* private fields */ }Expand description
Replays workflow histories against registered workflow implementations.
Implementations
Sourceimpl WorkflowReplayer
impl WorkflowReplayer
Sourcepub fn new(
options: WorkflowReplayerOptions,
) -> Result<Self, WorkflowReplayError>
pub fn new( options: WorkflowReplayerOptions, ) -> Result<Self, WorkflowReplayError>
Construct a replayer and apply its worker plugins.
Sourcepub fn options(&self) -> &WorkflowReplayerOptions
pub fn options(&self) -> &WorkflowReplayerOptions
Return the configured replay options.
Sourcepub async fn replay_workflow(
&self,
history: WorkflowHistory,
) -> Result<(), WorkflowReplayError>
pub async fn replay_workflow( &self, history: WorkflowHistory, ) -> Result<(), WorkflowReplayError>
Replay one history and return an error if it is incompatible with workflow code.
Sourcepub async fn replay_workflows(
&self,
histories: impl IntoIterator<Item = WorkflowHistory>,
) -> Result<Vec<WorkflowReplayResult>, WorkflowReplayError>
pub async fn replay_workflows( &self, histories: impl IntoIterator<Item = WorkflowHistory>, ) -> Result<Vec<WorkflowReplayResult>, WorkflowReplayError>
Replay histories using one replay worker and return outcomes in input order.