WorkflowReplayerOptions

Struct WorkflowReplayerOptions 

#[non_exhaustive]
pub struct WorkflowReplayerOptions { pub namespace: String, pub task_queue: String, pub data_converter: DataConverter, pub workflow_failure_errors: HashSet<WorkflowErrorType>, pub workflow_types_to_failure_errors: HashMap<String, HashSet<WorkflowErrorType>>, pub detect_nondeterministic_futures: bool, pub patch_activation_callback: Option<PatchActivationCallback>, /* private fields */ }
Options for constructing a workflow replayer.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
namespace: String

Namespace exposed to workflow code during replay.

task_queue: String

Task queue exposed to workflow code during replay.

data_converter: DataConverter

Data converter used for workflow payloads.

workflow_failure_errors: HashSet<WorkflowErrorType>

Worker-level workflow errors that should fail workflow executions.

workflow_types_to_failure_errors: HashMap<String, HashSet<WorkflowErrorType>>

Per-workflow-type errors that should fail workflow executions.

detect_nondeterministic_futures: bool

Whether to detect nondeterministic future usage in workflow code.

patch_activation_callback: Option<PatchActivationCallback>

Callback controlling first non-replay patch decisions.

Implementations

Source

impl WorkflowReplayerOptions

pub fn new() -> WorkflowReplayerOptionsBuilder

Create an instance of WorkflowReplayerOptions using the builder syntax

Source

impl WorkflowReplayerOptions

pub fn worker_interceptor<I: WorkerInterceptor + 'static>( &mut self, interceptor: I, ) -> &mut Self

Append a worker interceptor used during replay.

pub fn workflow_interceptor( &mut self, constructor: WorkflowInterceptorConstructor, ) -> &mut Self

Append a workflow interceptor constructor used during replay.

pub fn register_workflow<W>( &mut self, ) -> Result<&mut Self, WorkflowRegistrationError>

Register a workflow implementation for replay.

pub fn register_workflow_with_factory<W, F>( &mut self, factory: F, ) -> Result<&mut Self, WorkflowRegistrationError>
where W: WorkflowImplementation, <W::Run as WorkflowDefinition>::Input: Send, F: Fn() -> W + Send + Sync + 'static,

Register a workflow using a custom instance factory.

pub fn register_workflow_interceptors( &mut self, constructors: Vec<WorkflowInterceptorConstructor>, ) -> &mut Self

Set the ordered constructors used to create workflow interceptors for each workflow instance.

This replaces any previously configured workflow interceptor constructors.

pub fn workflows(&self) -> WorkflowDefinitions

Returns all the registered workflows by cloning the current set.