WorkflowReplayerOptionsBuilder

Struct WorkflowReplayerOptionsBuilder 

pub struct WorkflowReplayerOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> WorkflowReplayerOptionsBuilder<S>

pub fn build(self) -> WorkflowReplayerOptions
where S: IsComplete,

Finish building and return the requested object

pub fn namespace( self, value: impl Into<String>, ) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_REPLAY_NAMESPACE.to_owned().

Namespace exposed to workflow code during replay.

pub fn maybe_namespace( self, value: Option<impl Into<String>>, ) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
where S::Namespace: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_REPLAY_NAMESPACE.to_owned().

Namespace exposed to workflow code during replay.

pub fn task_queue( self, value: impl Into<String>, ) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
where S::TaskQueue: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_REPLAY_TASK_QUEUE.to_owned().

Task queue exposed to workflow code during replay.

pub fn maybe_task_queue( self, value: Option<impl Into<String>>, ) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
where S::TaskQueue: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_REPLAY_TASK_QUEUE.to_owned().

Task queue exposed to workflow code during replay.

pub fn data_converter( self, value: DataConverter, ) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>

Optional (Some / Option setters). Default: <DataConverter as Default>::default().

Data converter used for workflow payloads.

pub fn maybe_data_converter( self, value: Option<DataConverter>, ) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>

Optional (Some / Option setters). Default: <DataConverter as Default>::default().

Data converter used for workflow payloads.

pub fn workflow_failure_errors( self, value: HashSet<WorkflowErrorType>, ) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>

Optional (Some / Option setters). Default: <HashSet<WorkflowErrorType> as Default>::default().

Worker-level workflow errors that should fail workflow executions.

pub fn maybe_workflow_failure_errors( self, value: Option<HashSet<WorkflowErrorType>>, ) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>

Optional (Some / Option setters). Default: <HashSet<WorkflowErrorType> as Default>::default().

Worker-level workflow errors that should fail workflow executions.

pub fn workflow_types_to_failure_errors( self, value: HashMap<String, HashSet<WorkflowErrorType>>, ) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>

Optional (Some / Option setters). Default: <HashMap<String, HashSet<WorkflowErrorType>> as Default>::default().

Per-workflow-type errors that should fail workflow executions.

pub fn maybe_workflow_types_to_failure_errors( self, value: Option<HashMap<String, HashSet<WorkflowErrorType>>>, ) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>

Optional (Some / Option setters). Default: <HashMap<String, HashSet<WorkflowErrorType>> as Default>::default().

Per-workflow-type errors that should fail workflow executions.

pub fn detect_nondeterministic_futures( self, value: bool, ) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>

Optional (Some / Option setters). Default: true.

Whether to detect nondeterministic future usage in workflow code.

pub fn maybe_detect_nondeterministic_futures( self, value: Option<bool>, ) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>

Optional (Some / Option setters). Default: true.

Whether to detect nondeterministic future usage in workflow code.

pub fn patch_activation_callback( self, value: PatchActivationCallback, ) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>

Optional (Some / Option setters). Callback controlling first non-replay patch decisions.

pub fn maybe_patch_activation_callback( self, value: Option<PatchActivationCallback>, ) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>

Optional (Some / Option setters). Callback controlling first non-replay patch decisions.

Source

impl<S: State> WorkflowReplayerOptionsBuilder<S>

pub fn worker_plugin<P: WorkerPlugin>(self, plugin: P) -> Self

Register a worker plugin with this replayer.

Experimental: This API may change or be removed.

pub fn worker_interceptor<I: WorkerInterceptor + 'static>( self, interceptor: I, ) -> Self

Append a worker interceptor used during replay.

pub fn workflow_interceptor( self, constructor: WorkflowInterceptorConstructor, ) -> Self

Append a workflow interceptor constructor used during replay.

pub fn register_workflow<W>(self) -> Result<Self, WorkflowRegistrationError>

Register a workflow implementation for replay.

pub fn register_workflow_with_factory<W, F>( self, factory: F, ) -> Result<Self, WorkflowRegistrationError>
where W: WorkflowImplementation, <W::Run as WorkflowDefinition>::Input: Send, F: Fn() -> W + Send + Sync + 'static,

Register a workflow using a custom instance factory.

pub fn register_workflow_interceptors( self, constructors: Vec<WorkflowInterceptorConstructor>, ) -> Self

Set the ordered constructors used to create workflow interceptors for each workflow instance.

This replaces any previously configured workflow interceptor constructors.

pub fn workflow_interceptor_constructors_mut( &mut self, ) -> &mut Vec<WorkflowInterceptorConstructor>

Get a mutable reference to the workflow interceptor constructors list.