pub struct WorkflowDefinitions { /* private fields */ }Expand description
Contains workflow registrations in a form ready for execution by workers.
Implementations
Sourceimpl WorkflowDefinitions
impl WorkflowDefinitions
Sourcepub fn register_workflow<W: WorkflowImplementation>(
&mut self,
) -> Result<&mut Self, WorkflowRegistrationError>
pub fn register_workflow<W: WorkflowImplementation>( &mut self, ) -> Result<&mut Self, WorkflowRegistrationError>
Register a workflow implementation.
Returns an error if a workflow with the same type is already registered.
Sourcepub fn register_workflow_run_with_factory<W, F>(
&mut self,
user_factory: F,
) -> Result<&mut Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
pub fn register_workflow_run_with_factory<W, F>(
&mut self,
user_factory: F,
) -> Result<&mut Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
Register a workflow with a custom factory for instance creation.
Returns an error if a workflow with the same type is already registered, or if the workflow
type defines an #[init] method.
Sourcepub fn workflow_definitions(
&self,
) -> impl Iterator<Item = &WorkflowDefinitionDescriptor> + '_
pub fn workflow_definitions( &self, ) -> impl Iterator<Item = &WorkflowDefinitionDescriptor> + '_
Returns an iterator over registered workflow definitions.