ActivityError

Enum ActivityError 

pub enum ActivityError {
    Retryable {
        source: Box<dyn Error + Send + Sync + 'static>,
        explicit_delay: Option<Duration>,
    },
    Cancelled {
        details: Option<Payload>,
    },
    NonRetryable(Box<dyn Error + Send + Sync + 'static>),
    WillCompleteAsync,
}
Returned as errors from activity functions.

Variants



Retryable

This error can be returned from activities to allow the explicit configuration of certain error properties. It’s also the default error type that arbitrary errors will be converted into.

Fields

source: Box<dyn Error + Send + Sync + 'static>

The underlying error

explicit_delay: Option<Duration>

If specified, the next retry (if there is one) will occur after this delay



Cancelled

Return this error to indicate your activity is cancelling

Fields

details: Option<Payload>

Some data to save as the cancellation reason



NonRetryable(Box<dyn Error + Send + Sync + 'static>)

Return this error to indicate that the activity should not be retried.



WillCompleteAsync

Return this error to indicate that the activity will be completed outside of this activity definition, by an external client.

Implementations

Source

impl ActivityError

pub fn cancelled() -> Self

Construct a cancelled error without details