pub enum ActivityError {
Retryable {
source: Box<dyn Error + Send + Sync + 'static>,
explicit_delay: Option<Duration>,
},
Cancelled {
details: Option<Payload>,
},
NonRetryable(Box<dyn Error + Send + Sync + 'static>),
WillCompleteAsync,
}Expand description
Returned as errors from activity functions.
Variants
Retryable
This error can be returned from activities to allow the explicit configuration of certain error properties. It’s also the default error type that arbitrary errors will be converted into.
Fields
Cancelled
Return this error to indicate your activity is cancelling
NonRetryable(Box<dyn Error + Send + Sync + 'static>)
Return this error to indicate that the activity should not be retried.
WillCompleteAsync
Return this error to indicate that the activity will be completed outside of this activity definition, by an external client.
Implementations
Sourceimpl ActivityError
impl ActivityError