pub struct ActivityContext { /* private fields */ }Expand description
Used within activities to get info, heartbeat management etc.
Implementations
Sourceimpl ActivityContext
impl ActivityContext
Sourcepub async fn cancelled(&self)
pub async fn cancelled(&self)
Returns a future the completes if and when the activity this was called inside has been cancelled
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if this activity has already been cancelled
Sourcepub fn heartbeat_details(&self) -> &ActivityHeartbeatDetails
pub fn heartbeat_details(&self) -> &ActivityHeartbeatDetails
Extract heartbeat details from last failed attempt. This is used in combination with retry policy.
Sourcepub async fn record_heartbeat<T>(
&self,
details: T,
) -> Result<(), PayloadConversionError>where
T: TemporalSerializable + 'static,
pub async fn record_heartbeat<T>(
&self,
details: T,
) -> Result<(), PayloadConversionError>where
T: TemporalSerializable + 'static,
Record a heartbeat with typed progress details for the currently executing activity.
Sourcepub fn info(&self) -> &ActivityInfo
pub fn info(&self) -> &ActivityInfo
Returns activity info of the executing activity
Sourcepub fn client(&self) -> Client
pub fn client(&self) -> Client
Return a client targeting the same Temporal service and namespace as this activity’s worker.
Sourcepub fn workflow_handle<W: HasWorkflowDefinition>(
&self,
) -> Option<WorkflowHandle<Client, W>>
pub fn workflow_handle<W: HasWorkflowDefinition>( &self, ) -> Option<WorkflowHandle<Client, W>>
Return a workflow handle for the workflow execution that started this activity, if any.