WorkflowTermination

Enum WorkflowTermination 

pub enum WorkflowTermination {
    Cancelled {
        details: Option<Box<dyn WorkflowOutputValue + Send + Sync>>,
    },
    Evicted,
    ContinueAsNew(Box<ContinueAsNewWorkflowExecution>),
    Failed(OutgoingWorkflowError),
}
Represents ways a workflow can terminate without producing a normal result.

Payload conversion errors returned by workflow operations propagated directly into WorkflowTermination, such as with ?, will fail the current Workflow Task so it can be retried.

Wrap an error in an ApplicationFailure to explicitly fail the Workflow Execution.

Variants



Cancelled

The Workflow Execution was cancelled, optionally with user-supplied details.

Fields

details: Option<Box<dyn WorkflowOutputValue + Send + Sync>>

Optional cancellation details.



Evicted

The workflow was evicted and must stop without producing a completion command.



ContinueAsNew(Box<ContinueAsNewWorkflowExecution>)

The workflow requested a new run with the supplied command attributes.



Failed(OutgoingWorkflowError)

The Workflow Execution failed with an error already converted for outbound handling.

Implementations

Source

impl WorkflowTermination

pub fn cancelled() -> WorkflowTermination

Construct a cancelled workflow termination without details.

pub fn cancelled_with_details<T>(details: T) -> WorkflowTermination
where T: TemporalSerializable + Send + Sync + 'static,

Construct a cancelled workflow termination with details that will be converted using the active payload converter.

pub fn continue_as_new( can: ContinueAsNewWorkflowExecution, ) -> WorkflowTermination

Constructs a termination that asks the worker to continue the workflow as a new run.

pub fn failed_application(err: ApplicationFailure) -> WorkflowTermination