Module error

Module error 

Shared SDK error re-exports.

Structs

ApplicationFailure
User-authored application failure metadata that can be converted into a Temporal failure.

Enums

ActivityExecutionError
Error type for activity execution outcomes.
ApplicationErrorCategory
Categorizes an ApplicationFailure to hint at how the server and tooling should treat it.
ChildWorkflowExecutionError
Error returned when a child workflow execution fails.
ChildWorkflowStartError
Error returned when starting a child workflow fails.
OutgoingActivityError
A typed outbound activity error.
OutgoingError
A typed outbound error surface used before encoding to a Temporal failure proto.
OutgoingWorkflowError
A typed outbound workflow failure.
WorkflowRegistrationError
Error returned when a workflow cannot be registered.
WorkflowSignalError
Error returned when signaling a workflow fails.