Shared SDK error re-exports.
Structs
- Application
Failure - User-authored application failure metadata that can be converted into a Temporal failure.
Enums
- Activity
Execution Error - Error type for activity execution outcomes.
- Application
Error Category - Categorizes an
ApplicationFailureto hint at how the server and tooling should treat it. - Child
Workflow Execution Error - Error returned when a child workflow execution fails.
- Child
Workflow Start Error - Error returned when starting a child workflow fails.
- Outgoing
Activity Error - A typed outbound activity error.
- Outgoing
Error - A typed outbound error surface used before encoding to a Temporal failure proto.
- Outgoing
Workflow Error - A typed outbound workflow failure.
- Workflow
Registration Error - Error returned when a workflow cannot be registered.
- Workflow
Signal Error - Error returned when signaling a workflow fails.