pub struct InterceptorWithNext { /* private fields */ }Expand description
Supports the composition of interceptors
Implementations
Sourceimpl InterceptorWithNext
impl InterceptorWithNext
Sourcepub fn new(inner: Box<dyn WorkerInterceptor>) -> Self
pub fn new(inner: Box<dyn WorkerInterceptor>) -> Self
Create from an existing interceptor, can be used to initialize a chain of interceptors
Sourcepub fn set_next(
&mut self,
next: Box<dyn WorkerInterceptor>,
) -> &mut InterceptorWithNext
pub fn set_next( &mut self, next: Box<dyn WorkerInterceptor>, ) -> &mut InterceptorWithNext
Sets the next interceptor, and then returns that interceptor, wrapped by InterceptorWithNext. You can keep calling this method on it to extend the chain.