Experimental APIs for configuring clients and workers with reusable plugins. Experimental plugin APIs for configuring workers and clients from reusable values.
Modules
- simple_
plugin_ builder - Tools for manipulating the type state of
SimplePluginBuilder.
Structs
- Client
AndWorker Plugin - A container for a plugin that implements both
ClientPluginandWorkerPlugin. - Simple
Plugin - A plugin assembled from declarative values or functions of existing values.
- Simple
Plugin Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Definitions - Contains workflow registrations in a form ready for execution by workers.
Enums
- Simple
Plugin Option - A simple plugin field that either supplies a value or customizes the existing value.
Traits
- Worker
Plugin - Configures worker options before the worker is created.