Trait State Copy item path Source pub trait State: Sized {
type DataConverter ;
type ClientInterceptors ;
type WorkerInterceptors ;
type ActivityInboundInterceptors ;
type WorkflowInterceptors ;
type Activities ;
type Workflows ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member data_converter.
It can implement either IsSet or IsUnset
Type state of the member client_interceptors.
It can implement either IsSet or IsUnset
Type state of the member worker_interceptors.
It can implement either IsSet or IsUnset
Type state of the member activity_inbound_interceptors.
It can implement either IsSet or IsUnset
Type state of the member workflow_interceptors.
It can implement either IsSet or IsUnset
Type state of the member activities.
It can implement either IsSet or IsUnset
Type state of the member workflows.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".