pub struct SimplePlugin { /* private fields */ }Expand description
A plugin assembled from declarative values or functions of existing values.
Scalar values replace the corresponding option, while collection values append. Functions receive the existing field and replace it with their return value, except that returned workflow definitions are merged into the existing definitions.
use temporalio_client::ClientOptions;
use temporalio_common::data_converters::DataConverter;
use temporalio_sdk::SimplePlugin;
let plugin = SimplePlugin::builder("my-plugin")
.data_converter(|existing: Option<DataConverter>| existing.unwrap_or_default())
.build();
let client_options = ClientOptions::new("default").plugin(plugin).build();Worker configuration declared by this combined plugin is automatically propagated through the configured client when a worker is created.
Experimental: This API may change or be removed.
Implementations
Sourceimpl SimplePlugin
impl SimplePlugin
Sourcepub fn builder(name: impl Into<String>) -> SimplePluginBuilder
pub fn builder(name: impl Into<String>) -> SimplePluginBuilder
Create an instance of SimplePlugin using the builder syntax