pub struct Runtime(/* private fields */);Expand description
Holds shared state and components used by Rust SDK workers.
Implementations
Sourceimpl Runtime
impl Runtime
Sourcepub fn new<F>(
options: RuntimeOptions,
tokio_builder: TokioRuntimeBuilder<F>,
) -> Result<Self, Error>
pub fn new<F>( options: RuntimeOptions, tokio_builder: TokioRuntimeBuilder<F>, ) -> Result<Self, Error>
Creates a runtime with a newly constructed Tokio runtime.
Sourcepub fn new_assume_tokio(options: RuntimeOptions) -> Result<Self, Error>
pub fn new_assume_tokio(options: RuntimeOptions) -> Result<Self, Error>
Creates a runtime using the currently active Tokio runtime.
Panics
Panics if there is no currently active Tokio runtime.
Sourcepub fn new_assume_tokio_initialized_telem(
telemetry: TelemetryInstance,
heartbeat_interval: Option<Duration>,
) -> Self
pub fn new_assume_tokio_initialized_telem( telemetry: TelemetryInstance, heartbeat_interval: Option<Duration>, ) -> Self
Creates a runtime from an initialized telemetry instance using the currently active Tokio runtime.
Panics
Panics if there is no currently active Tokio runtime.
Methods from Deref<Target = CoreRuntime>
Sourcepub fn tokio_handle(&self) -> Handle
pub fn tokio_handle(&self) -> Handle
Get a handle to the tokio runtime used by this Core runtime.
Sourcepub fn telemetry(&self) -> &TelemetryInstance
pub fn telemetry(&self) -> &TelemetryInstance
Return a reference to the owned TelemetryInstance
Sourcepub fn telemetry_mut(&mut self) -> &mut TelemetryInstance
pub fn telemetry_mut(&mut self) -> &mut TelemetryInstance
Return a mutable reference to the owned TelemetryInstance