Worker concurrency tuning. Worker concurrency tuning for SDK workers.
Modules
- resource_
based_ slot_ options_ builder - Tools for manipulating the type state of
ResourceBasedSlotOptionsBuilder. - resource_
based_ tuner_ builder - Tools for manipulating the type state of
ResourceBasedTunerBuilder. - resource_
based_ tuner_ options_ builder - Tools for manipulating the type state of
ResourceBasedTunerOptionsBuilder. - resource_
based_ tuner_ with_ controller_ builder - Tools for manipulating the type state of
ResourceBasedTunerWithControllerBuilder. - tuner_
holder_ builder - Tools for manipulating the type state of
TunerHolderBuilder.
Structs
- Fixed
Size Slot Supplier - A fixed-size slot supplier.
- Resource
Based Controller - Coordinates resource-based slot allocation across multiple workers.
- Resource
Based Slot Options - Per-task-type options for resource-based slots.
- Resource
Based Slot Options Builder - Use builder syntax to set the inputs and finish with
build(). - Resource
Based Slots ForType - Resource-based slot settings for one task type.
- Resource
Based Tuner - A resource-based tuner that creates a controller scoped to its worker.
- Resource
Based Tuner Builder - Use builder syntax to set the inputs and finish with
build(). - Resource
Based Tuner Options - Target resource usage for resource-based tuning.
- Resource
Based Tuner Options Builder - Use builder syntax to set the inputs and finish with
build(). - Resource
Based Tuner With Controller - A resource-based tuner governed by a controller shared across workers.
- Resource
Based Tuner With Controller Builder - Use builder syntax to set the inputs and finish with
build(). - Tuner
Holder - A tuner composed from independently selected slot suppliers.
- Tuner
Holder Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- Slot
Supplier - A fixed-size or resource-based slot supplier.
- Worker
Tuner - A worker tuner configuration.