#[non_exhaustive]pub struct ActivityOptions {
pub close_timeouts: ActivityCloseTimeouts,
pub activity_id: Option<String>,
pub task_queue: Option<String>,
pub schedule_to_start_timeout: Option<Duration>,
pub heartbeat_timeout: Option<Duration>,
pub cancellation_type: ActivityCancellationType,
pub retry_policy: Option<RetryPolicy>,
pub summary: Option<String>,
pub priority: Option<Priority>,
pub do_not_eagerly_execute: bool,
}Expand description
Options for scheduling an activity
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.close_timeouts: ActivityCloseTimeoutsTimeouts for activity completion.
See ActivityCloseTimeouts for the meaning of each timeout variant.
activity_id: Option<String>Identifier to use for tracking the activity in Workflow history.
The activityId can be accessed by the activity function.
Does not need to be unique.
If None use the context’s sequence number
task_queue: Option<String>Task queue to schedule the activity in
If None, use the same task queue as the parent workflow.
schedule_to_start_timeout: Option<Duration>Time that the Activity Task can stay in the Task Queue before it is picked up by a Worker.
Do not specify this timeout unless using host specific Task Queues for Activity Tasks are
being used for routing.
schedule_to_start_timeout is always non-retryable.
Retrying after this timeout doesn’t make sense as it would just put the Activity Task back
into the same Task Queue.
heartbeat_timeout: Option<Duration>Heartbeat interval. Activity must heartbeat before this interval passes after a last heartbeat or activity start.
cancellation_type: ActivityCancellationTypeDetermines what the SDK does when the Activity is cancelled.
retry_policy: Option<RetryPolicy>Activity retry policy
summary: Option<String>Summary of the activity
priority: Option<Priority>Priority for the activity
do_not_eagerly_execute: boolIf true, disable eager execution for this activity
Implementations
Sourceimpl ActivityOptions
impl ActivityOptions
Sourcepub fn with_close_timeouts(
close_timeouts: ActivityCloseTimeouts,
) -> ActivityOptionsBuilder
pub fn with_close_timeouts( close_timeouts: ActivityCloseTimeouts, ) -> ActivityOptionsBuilder
Create an instance of ActivityOptions using the builder syntax
Sourceimpl ActivityOptions
impl ActivityOptions
Sourcepub fn with_start_to_close_timeout(duration: Duration) -> ActivityOptionsBuilder
pub fn with_start_to_close_timeout(duration: Duration) -> ActivityOptionsBuilder
Returns a builder with close_timeout set to ActivityCloseTimeouts::StartToClose.
Sourcepub fn with_schedule_to_close_timeout(
duration: Duration,
) -> ActivityOptionsBuilder
pub fn with_schedule_to_close_timeout( duration: Duration, ) -> ActivityOptionsBuilder
Returns a builder with close_timeout set to ActivityCloseTimeouts::ScheduleToClose.
Sourcepub fn start_to_close_timeout(duration: Duration) -> Self
pub fn start_to_close_timeout(duration: Duration) -> Self
Creates activity options with only start_to_close_timeout set.
If you need additional fields set, use Self::with_start_to_close_timeout.
Sourcepub fn schedule_to_close_timeout(duration: Duration) -> Self
pub fn schedule_to_close_timeout(duration: Duration) -> Self
Creates activity options with only schedule_to_close_timeout set.
If you need additional fields set, use Self::with_schedule_to_close_timeout.