ActivityOptions

Struct ActivityOptions 

pub struct ActivityOptions {
    pub activity_id: Option<String>,
    pub task_queue: Option<String>,
    pub schedule_to_start_timeout: Option<Duration>,
    pub start_to_close_timeout: Option<Duration>,
    pub schedule_to_close_timeout: Option<Duration>,
    pub heartbeat_timeout: Option<Duration>,
    pub cancellation_type: ActivityCancellationType,
    pub retry_policy: Option<RetryPolicy>,
    pub summary: Option<String>,
    pub priority: Option<Priority>,
    pub do_not_eagerly_execute: bool,
}
Options for scheduling an activity

Fields

activity_id: Option<String>

Identifier to use for tracking the activity in Workflow history. The activityId can be accessed by the activity function. Does not need to be unique.

If None use the context’s sequence number

task_queue: Option<String>

Task queue to schedule the activity in

If None, use the same task queue as the parent workflow.

schedule_to_start_timeout: Option<Duration>

Time that the Activity Task can stay in the Task Queue before it is picked up by a Worker. Do not specify this timeout unless using host specific Task Queues for Activity Tasks are being used for routing. schedule_to_start_timeout is always non-retryable. Retrying after this timeout doesn’t make sense as it would just put the Activity Task back into the same Task Queue.

start_to_close_timeout: Option<Duration>

Maximum time of a single Activity execution attempt. Note that the Temporal Server doesn’t detect Worker process failures directly. It relies on this timeout to detect that an Activity that didn’t complete on time. So this timeout should be as short as the longest possible execution of the Activity body. Potentially long running Activities must specify heartbeat_timeout and heartbeat from the activity periodically for timely failure detection. Either this option or schedule_to_close_timeout is required.

schedule_to_close_timeout: Option<Duration>

Total time that a workflow is willing to wait for Activity to complete. schedule_to_close_timeout limits the total time of an Activity’s execution including retries (use start_to_close_timeout to limit the time of a single attempt). Either this option or start_to_close_timeout is required.

heartbeat_timeout: Option<Duration>

Heartbeat interval. Activity must heartbeat before this interval passes after a last heartbeat or activity start.

cancellation_type: ActivityCancellationType

Determines what the SDK does when the Activity is cancelled.

retry_policy: Option<RetryPolicy>

Activity retry policy

summary: Option<String>

Summary of the activity

priority: Option<Priority>

Priority for the activity

do_not_eagerly_execute: bool

If true, disable eager execution for this activity