#[non_exhaustive]pub struct ChildWorkflowOptions {Show 13 fields
pub workflow_id: Option<String>,
pub task_queue: Option<String>,
pub cancel_type: ChildWorkflowCancellationType,
pub parent_close_policy: ParentClosePolicy,
pub static_summary: Option<String>,
pub static_details: Option<String>,
pub id_reuse_policy: WorkflowIdReusePolicy,
pub execution_timeout: Option<Duration>,
pub run_timeout: Option<Duration>,
pub task_timeout: Option<Duration>,
pub cron_schedule: Option<String>,
pub search_attributes: Option<SearchAttributes>,
pub priority: Option<Priority>,
}Expand description
Options for scheduling a child workflow
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_id: Option<String>Workflow ID. If unset or empty, the parent workflow generates a deterministic UUIDv4.
task_queue: Option<String>Task queue to schedule the workflow in
If None, use the same task queue as the parent workflow.
cancel_type: ChildWorkflowCancellationTypeCancellation strategy for the child workflow
parent_close_policy: ParentClosePolicyHow to respond to parent workflow ending
static_summary: Option<String>Static summary of the child workflow
static_details: Option<String>Static details of the child workflow
id_reuse_policy: WorkflowIdReusePolicySet the policy for reusing the workflow id
execution_timeout: Option<Duration>Optionally set the execution timeout for the workflow
run_timeout: Option<Duration>Optionally indicates the default run timeout for a workflow run
task_timeout: Option<Duration>Optionally indicates the default task timeout for a workflow run
cron_schedule: Option<String>Optionally set a cron schedule for the workflow
search_attributes: Option<SearchAttributes>Additional search attributes to set on the child workflow.
priority: Option<Priority>Priority for the workflow
Implementations
Sourceimpl ChildWorkflowOptions
impl ChildWorkflowOptions
Sourcepub fn builder() -> ChildWorkflowOptionsBuilder
pub fn builder() -> ChildWorkflowOptionsBuilder
Create an instance of ChildWorkflowOptions using the builder syntax
Sourceimpl ChildWorkflowOptions
impl ChildWorkflowOptions
Sourcepub fn workflow_id(workflow_id: String) -> ChildWorkflowOptions
pub fn workflow_id(workflow_id: String) -> ChildWorkflowOptions
Construct a ChildWorkflowOptions with the specified workflow_id.
Shorthand for ChildWorkflowOptions::builder().workflow_id(Some(workflow_id)).build()