#[non_exhaustive]pub struct NexusOperationOptions {
pub endpoint: String,
pub service: String,
pub operation: String,
pub input: Option<Payload>,
pub schedule_to_close_timeout: Option<Duration>,
pub nexus_header: HashMap<String, String>,
pub cancellation_type: Option<NexusOperationCancellationType>,
pub cancellation_token: Option<WorkflowCancellationToken>,
pub schedule_to_start_timeout: Option<Duration>,
pub start_to_close_timeout: Option<Duration>,
}Expand description
Options for Nexus Operations
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: StringEndpoint name, must exist in the endpoint registry or this command will fail.
service: StringService name.
operation: StringOperation name.
input: Option<Payload>Input for the operation. The server converts this into Nexus request content and the appropriate content headers internally when sending the StartOperation request. On the handler side, if it is also backed by Temporal, the content is transformed back to the original Payload sent in this command.
schedule_to_close_timeout: Option<Duration>Schedule-to-close timeout for this operation. Indicates how long the caller is willing to wait for operation completion. Calls are retried internally by the server.
nexus_header: HashMap<String, String>Header to attach to the Nexus request. Users are responsible for encrypting sensitive data in this header as it is stored in workflow history and transmitted to external services as-is. This is useful for propagating tracing information. Note these headers are not the same as Temporal headers on internal activities and child workflows, these are transmitted to Nexus operations that may be external and are not traditional payloads.
cancellation_type: Option<NexusOperationCancellationType>Cancellation type for the operation
cancellation_token: Option<WorkflowCancellationToken>Cancellation token for this operation. None inherits workflow cancellation.
schedule_to_start_timeout: Option<Duration>Schedule-to-start timeout for this operation. Indicates how long the caller is willing to wait for the operation to be started (or completed if synchronous) by the handler. If the operation is not started within this timeout, it will fail with TIMEOUT_TYPE_SCHEDULE_TO_START. If not set or zero, no schedule-to-start timeout is enforced.
start_to_close_timeout: Option<Duration>Start-to-close timeout for this operation. Indicates how long the caller is willing to wait for an asynchronous operation to complete after it has been started. If the operation does not complete within this timeout after starting, it will fail with TIMEOUT_TYPE_START_TO_CLOSE. Only applies to asynchronous operations. Synchronous operations ignore this timeout. If not set or zero, no start-to-close timeout is enforced.
Implementations
Sourceimpl NexusOperationOptions
impl NexusOperationOptions
Sourcepub fn builder() -> NexusOperationOptionsBuilder
pub fn builder() -> NexusOperationOptionsBuilder
Create an instance of NexusOperationOptions using the builder syntax