pub struct PendingChildWorkflow {
pub status: Status,
/* private fields */
}Expand description
Child workflow in pending state
Fields
status: StatusThe status of the child workflow start
Implementations
Sourceimpl PendingChildWorkflow
impl PendingChildWorkflow
Sourcepub fn into_started(self) -> Option<StartedChildWorkflow>
pub fn into_started(self) -> Option<StartedChildWorkflow>
Returns None if the child did not start successfully. The returned StartedChildWorkflow
can be used to wait on, signal, or cancel the child workflow.