#[non_exhaustive]pub struct WorkflowContextView {Show 18 fields
pub workflow_id: String,
pub run_id: String,
pub workflow_type: String,
pub task_queue: String,
pub namespace: String,
pub attempt: u32,
pub first_execution_run_id: String,
pub continued_from_run_id: Option<String>,
pub start_time: Option<SystemTime>,
pub execution_timeout: Option<Duration>,
pub run_timeout: Option<Duration>,
pub task_timeout: Option<Duration>,
pub parent: Option<ParentWorkflowInfo>,
pub root: Option<RootWorkflowInfo>,
pub retry_policy: Option<RetryPolicy>,
pub cron_schedule: Option<String>,
pub memo: Option<Memo>,
pub search_attributes: Option<SearchAttributes>,
}Expand description
Read-only view of workflow context for use in init and query handlers.
This provides access to workflow information but cannot issue commands.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_id: StringThe workflow’s unique identifier
run_id: StringThe run id of this workflow execution
workflow_type: StringThe workflow type name
task_queue: StringThe task queue this workflow is executing on
namespace: StringThe namespace this workflow is executing in
attempt: u32The current attempt number (starting from 1)
first_execution_run_id: StringThe run id of the very first execution in the chain
continued_from_run_id: Option<String>The run id of the previous execution if this is a continuation
start_time: Option<SystemTime>When the workflow execution started
execution_timeout: Option<Duration>Total workflow execution timeout including retries and continue as new
run_timeout: Option<Duration>Timeout of a single workflow run
task_timeout: Option<Duration>Timeout of a single workflow task
parent: Option<ParentWorkflowInfo>Information about the parent workflow, if this is a child workflow
root: Option<RootWorkflowInfo>Information about the root workflow in the execution chain
retry_policy: Option<RetryPolicy>The workflow’s retry policy
cron_schedule: Option<String>If this workflow runs on a cron schedule
memo: Option<Memo>User-defined memo
search_attributes: Option<SearchAttributes>Initial search attributes