pub struct SyncWorkflowInterceptorContext { /* private fields */ }Expand description
Workflow execution context available to sync-only inbound interceptors.
Implementations
Sourceimpl SyncWorkflowInterceptorContext
impl SyncWorkflowInterceptorContext
Sourcepub fn context_value<K>(&self) -> Option<Rc<<K as WorkflowContextKey>::Value>>where
K: WorkflowContextKey,
pub fn context_value<K>(&self) -> Option<Rc<<K as WorkflowContextKey>::Value>>where
K: WorkflowContextKey,
Return the value associated with key type K in the current workflow context scope.
Sourcepub fn with_context_value<K, R>(
&self,
value: <K as WorkflowContextKey>::Value,
f: impl FnOnce() -> R,
) -> Rwhere
K: WorkflowContextKey,
pub fn with_context_value<K, R>(
&self,
value: <K as WorkflowContextKey>::Value,
f: impl FnOnce() -> R,
) -> Rwhere
K: WorkflowContextKey,
Run synchronous interceptor code with value installed for key type K.
This is intended for query and update-validator interceptor chains, which cannot await.
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
Return the workflow’s unique identifier.
Sourcepub fn task_queue(&self) -> &str
pub fn task_queue(&self) -> &str
Return the task queue the workflow is executing in.
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
Return the workflow type name.
Sourcepub fn cancellation_token(&self) -> WorkflowCancellationToken
pub fn cancellation_token(&self) -> WorkflowCancellationToken
Return the workflow’s root cancellation token.
Sourcepub fn workflow_time(&self) -> Option<SystemTime>
pub fn workflow_time(&self) -> Option<SystemTime>
Return the current time according to the workflow.
Sourcepub fn history_length(&self) -> u32
pub fn history_length(&self) -> u32
Return the length of history so far at this point in the workflow.
Sourcepub fn search_attributes(&self) -> SearchAttributes
pub fn search_attributes(&self) -> SearchAttributes
Return current values for workflow search attributes.
Sourcepub fn is_replaying(&self) -> bool
pub fn is_replaying(&self) -> bool
Returns true if the current workflow task is happening under replay.
Sourcepub fn is_replaying_history_events(&self) -> bool
pub fn is_replaying_history_events(&self) -> bool
Returns true if the current work is replaying history events.
Sourcepub fn payload_converter(&self) -> &PayloadConverter
pub fn payload_converter(&self) -> &PayloadConverter
Returns the payload converter used by the worker running this workflow.