pub trait WorkflowOutputValue:
Any
+ TemporalSerializable
+ Sealed {
// Required method
fn as_any(&self) -> &(dyn Any + 'static);
}Expand description
Type-erased workflow output carried through the workflow interceptor chain.
Required Methods
Implementations
Sourceimpl dyn WorkflowOutputValue
impl dyn WorkflowOutputValue
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: Any,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: Any,
Attempt to access the workflow output as a concrete type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".