#[non_exhaustive]pub struct WorkflowReplayerOptions {
pub namespace: String,
pub task_queue: String,
pub data_converter: DataConverter,
pub workflow_failure_errors: HashSet<WorkflowErrorType>,
pub workflow_types_to_failure_errors: HashMap<String, HashSet<WorkflowErrorType>>,
pub detect_nondeterministic_futures: bool,
pub patch_activation_callback: Option<PatchActivationCallback>,
/* private fields */
}Expand description
Options for constructing a workflow replayer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespace: StringNamespace exposed to workflow code during replay.
task_queue: StringTask queue exposed to workflow code during replay.
data_converter: DataConverterData converter used for workflow payloads.
workflow_failure_errors: HashSet<WorkflowErrorType>Worker-level workflow errors that should fail workflow executions.
workflow_types_to_failure_errors: HashMap<String, HashSet<WorkflowErrorType>>Per-workflow-type errors that should fail workflow executions.
detect_nondeterministic_futures: boolWhether to detect nondeterministic future usage in workflow code.
patch_activation_callback: Option<PatchActivationCallback>Callback controlling first non-replay patch decisions.
Implementations
Sourceimpl WorkflowReplayerOptions
impl WorkflowReplayerOptions
Sourcepub fn new() -> WorkflowReplayerOptionsBuilder
pub fn new() -> WorkflowReplayerOptionsBuilder
Create an instance of WorkflowReplayerOptions using the builder syntax
Sourceimpl WorkflowReplayerOptions
impl WorkflowReplayerOptions
Sourcepub fn worker_interceptor<I: WorkerInterceptor + 'static>(
&mut self,
interceptor: I,
) -> &mut Self
pub fn worker_interceptor<I: WorkerInterceptor + 'static>( &mut self, interceptor: I, ) -> &mut Self
Append a worker interceptor used during replay.
Sourcepub fn workflow_interceptor(
&mut self,
constructor: WorkflowInterceptorConstructor,
) -> &mut Self
pub fn workflow_interceptor( &mut self, constructor: WorkflowInterceptorConstructor, ) -> &mut Self
Append a workflow interceptor constructor used during replay.
Sourcepub fn register_workflow<W>(
&mut self,
) -> Result<&mut Self, WorkflowRegistrationError>
pub fn register_workflow<W>( &mut self, ) -> Result<&mut Self, WorkflowRegistrationError>
Register a workflow implementation for replay.
Sourcepub fn register_workflow_with_factory<W, F>(
&mut self,
factory: F,
) -> Result<&mut Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
pub fn register_workflow_with_factory<W, F>(
&mut self,
factory: F,
) -> Result<&mut Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
Register a workflow using a custom instance factory.
Sourcepub fn register_workflow_interceptors(
&mut self,
constructors: Vec<WorkflowInterceptorConstructor>,
) -> &mut Self
pub fn register_workflow_interceptors( &mut self, constructors: Vec<WorkflowInterceptorConstructor>, ) -> &mut Self
Set the ordered constructors used to create workflow interceptors for each workflow instance.
This replaces any previously configured workflow interceptor constructors.
Sourcepub fn workflows(&self) -> WorkflowDefinitions
pub fn workflows(&self) -> WorkflowDefinitions
Returns all the registered workflows by cloning the current set.