pub struct WorkflowReplayerOptionsBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> WorkflowReplayerOptionsBuilder<S>
impl<S: State> WorkflowReplayerOptionsBuilder<S>
Sourcepub fn build(self) -> WorkflowReplayerOptionswhere
S: IsComplete,
pub fn build(self) -> WorkflowReplayerOptionswhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn namespace(
self,
value: impl Into<String>,
) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
pub fn namespace( self, value: impl Into<String>, ) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
Sourcepub fn maybe_namespace(
self,
value: Option<impl Into<String>>,
) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
pub fn maybe_namespace( self, value: Option<impl Into<String>>, ) -> WorkflowReplayerOptionsBuilder<SetNamespace<S>>
Sourcepub fn task_queue(
self,
value: impl Into<String>,
) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
pub fn task_queue( self, value: impl Into<String>, ) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
Sourcepub fn maybe_task_queue(
self,
value: Option<impl Into<String>>,
) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
pub fn maybe_task_queue( self, value: Option<impl Into<String>>, ) -> WorkflowReplayerOptionsBuilder<SetTaskQueue<S>>
Sourcepub fn data_converter(
self,
value: DataConverter,
) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>where
S::DataConverter: IsUnset,
pub fn data_converter(
self,
value: DataConverter,
) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>where
S::DataConverter: IsUnset,
Sourcepub fn maybe_data_converter(
self,
value: Option<DataConverter>,
) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>where
S::DataConverter: IsUnset,
pub fn maybe_data_converter(
self,
value: Option<DataConverter>,
) -> WorkflowReplayerOptionsBuilder<SetDataConverter<S>>where
S::DataConverter: IsUnset,
Sourcepub fn workflow_failure_errors(
self,
value: HashSet<WorkflowErrorType>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>where
S::WorkflowFailureErrors: IsUnset,
pub fn workflow_failure_errors(
self,
value: HashSet<WorkflowErrorType>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>where
S::WorkflowFailureErrors: IsUnset,
Sourcepub fn maybe_workflow_failure_errors(
self,
value: Option<HashSet<WorkflowErrorType>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>where
S::WorkflowFailureErrors: IsUnset,
pub fn maybe_workflow_failure_errors(
self,
value: Option<HashSet<WorkflowErrorType>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowFailureErrors<S>>where
S::WorkflowFailureErrors: IsUnset,
Sourcepub fn workflow_types_to_failure_errors(
self,
value: HashMap<String, HashSet<WorkflowErrorType>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>where
S::WorkflowTypesToFailureErrors: IsUnset,
pub fn workflow_types_to_failure_errors(
self,
value: HashMap<String, HashSet<WorkflowErrorType>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>where
S::WorkflowTypesToFailureErrors: IsUnset,
Sourcepub fn maybe_workflow_types_to_failure_errors(
self,
value: Option<HashMap<String, HashSet<WorkflowErrorType>>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>where
S::WorkflowTypesToFailureErrors: IsUnset,
pub fn maybe_workflow_types_to_failure_errors(
self,
value: Option<HashMap<String, HashSet<WorkflowErrorType>>>,
) -> WorkflowReplayerOptionsBuilder<SetWorkflowTypesToFailureErrors<S>>where
S::WorkflowTypesToFailureErrors: IsUnset,
Sourcepub fn detect_nondeterministic_futures(
self,
value: bool,
) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>where
S::DetectNondeterministicFutures: IsUnset,
pub fn detect_nondeterministic_futures(
self,
value: bool,
) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>where
S::DetectNondeterministicFutures: IsUnset,
Sourcepub fn maybe_detect_nondeterministic_futures(
self,
value: Option<bool>,
) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>where
S::DetectNondeterministicFutures: IsUnset,
pub fn maybe_detect_nondeterministic_futures(
self,
value: Option<bool>,
) -> WorkflowReplayerOptionsBuilder<SetDetectNondeterministicFutures<S>>where
S::DetectNondeterministicFutures: IsUnset,
Sourcepub fn patch_activation_callback(
self,
value: PatchActivationCallback,
) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>where
S::PatchActivationCallback: IsUnset,
pub fn patch_activation_callback(
self,
value: PatchActivationCallback,
) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>where
S::PatchActivationCallback: IsUnset,
Sourcepub fn maybe_patch_activation_callback(
self,
value: Option<PatchActivationCallback>,
) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>where
S::PatchActivationCallback: IsUnset,
pub fn maybe_patch_activation_callback(
self,
value: Option<PatchActivationCallback>,
) -> WorkflowReplayerOptionsBuilder<SetPatchActivationCallback<S>>where
S::PatchActivationCallback: IsUnset,
Sourceimpl<S: State> WorkflowReplayerOptionsBuilder<S>
impl<S: State> WorkflowReplayerOptionsBuilder<S>
Sourcepub fn worker_plugin<P: WorkerPlugin>(self, plugin: P) -> Self
pub fn worker_plugin<P: WorkerPlugin>(self, plugin: P) -> Self
Register a worker plugin with this replayer.
Experimental: This API may change or be removed.
Sourcepub fn worker_interceptor<I: WorkerInterceptor + 'static>(
self,
interceptor: I,
) -> Self
pub fn worker_interceptor<I: WorkerInterceptor + 'static>( self, interceptor: I, ) -> Self
Append a worker interceptor used during replay.
Sourcepub fn workflow_interceptor(
self,
constructor: WorkflowInterceptorConstructor,
) -> Self
pub fn workflow_interceptor( self, constructor: WorkflowInterceptorConstructor, ) -> Self
Append a workflow interceptor constructor used during replay.
Sourcepub fn register_workflow<W>(self) -> Result<Self, WorkflowRegistrationError>
pub fn register_workflow<W>(self) -> Result<Self, WorkflowRegistrationError>
Register a workflow implementation for replay.
Sourcepub fn register_workflow_with_factory<W, F>(
self,
factory: F,
) -> Result<Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
pub fn register_workflow_with_factory<W, F>(
self,
factory: F,
) -> Result<Self, WorkflowRegistrationError>where
W: WorkflowImplementation,
<W::Run as WorkflowDefinition>::Input: Send,
F: Fn() -> W + Send + Sync + 'static,
Register a workflow using a custom instance factory.
Sourcepub fn register_workflow_interceptors(
self,
constructors: Vec<WorkflowInterceptorConstructor>,
) -> Self
pub fn register_workflow_interceptors( self, constructors: Vec<WorkflowInterceptorConstructor>, ) -> Self
Set the ordered constructors used to create workflow interceptors for each workflow instance.
This replaces any previously configured workflow interceptor constructors.
Sourcepub fn workflow_interceptor_constructors_mut(
&mut self,
) -> &mut Vec<WorkflowInterceptorConstructor>
pub fn workflow_interceptor_constructors_mut( &mut self, ) -> &mut Vec<WorkflowInterceptorConstructor>
Get a mutable reference to the workflow interceptor constructors list.