Module workflows

Module workflows 

Workflow authoring APIs and native workflow registration helpers.

Structs

JoinAll
Future returned by join_all.
UpdateDefinitionDescriptor
Static metadata needed to route an update before constructing its handler future.
WorkflowDefinitionDescriptor
Static metadata a host needs before choosing and instantiating a workflow implementation.
WorkflowDefinitions
Contains workflow registrations in a form ready for execution by workers.

Enums

WorkflowError
Error type for workflow operations
WorkflowRegistrationError
Error returned when a workflow cannot be registered.

Traits

ExecutableAsyncSignal
Trait for executing asynchronous signal handlers on a workflow.
ExecutableAsyncUpdate
Trait for executing asynchronous update handlers on a workflow.
ExecutableQuery
Trait for executing query handlers on a workflow.
ExecutableSyncSignal
Trait for executing synchronous signal handlers on a workflow.
ExecutableSyncUpdate
Trait for executing synchronous update handlers on a workflow.
WorkflowImplementation
Trait implemented by workflow structs to enable execution by the worker.

Functions

join_all
Deterministic join_all for use in Temporal workflows.
serialize_result
Serialize a workflow result value to a payload.

Attribute Macros

workflow
Marks a struct as a workflow definition.
workflow_methods
Defines workflow methods for a workflow struct. Using this macro requires that you also depend on the temporalio_sdk crate.