Workflow authoring APIs and native workflow registration helpers.
Structs
- JoinAll
- Future returned by
join_all. - Update
Definition Descriptor - Static metadata needed to route an update before constructing its handler future.
- Workflow
Definition Descriptor - Static metadata a host needs before choosing and instantiating a workflow implementation.
- Workflow
Definitions - Contains workflow registrations in a form ready for execution by workers.
Enums
- Workflow
Error - Error type for workflow operations
- Workflow
Registration Error - Error returned when a workflow cannot be registered.
Traits
- Executable
Async Signal - Trait for executing asynchronous signal handlers on a workflow.
- Executable
Async Update - Trait for executing asynchronous update handlers on a workflow.
- Executable
Query - Trait for executing query handlers on a workflow.
- Executable
Sync Signal - Trait for executing synchronous signal handlers on a workflow.
- Executable
Sync Update - Trait for executing synchronous update handlers on a workflow.
- Workflow
Implementation - Trait implemented by workflow structs to enable execution by the worker.
Functions
- join_
all - Deterministic
join_allfor use in Temporal workflows. - serialize_
result - Serialize a workflow result value to a payload.
Attribute Macros
- workflow
- Marks a struct as a workflow definition.
- workflow_
methods - Defines workflow methods for a workflow struct. Using this macro requires that
you also depend on the
temporalio_sdkcrate.