#[workflow]Expand description
Marks a struct as a workflow definition.
By default, the struct name is used as the workflow type name. To specify a custom workflow
name, use #[run(name = "my-custom-workflow")] on the run method.
This attribute must be used in conjunction with #[workflow_methods] on an impl block.