pub struct WorkflowDefinitions { /* private fields */ }Expand description
Contains workflow registrations in a form ready for execution by workers.
Implementations
Sourceimpl WorkflowDefinitions
impl WorkflowDefinitions
Sourcepub fn register_workflow<W: WorkflowImplementer>(&mut self) -> &mut Self
pub fn register_workflow<W: WorkflowImplementer>(&mut self) -> &mut Self
Register a workflow implementation.
Sourcepub fn register_workflow_run_with_factory<W, F>(
&mut self,
user_factory: F,
) -> &mut Self
pub fn register_workflow_run_with_factory<W, F>( &mut self, user_factory: F, ) -> &mut Self
Register a workflow with a custom factory for instance creation.
Sourcepub fn workflow_types(&self) -> impl Iterator<Item = &'static str> + '_
pub fn workflow_types(&self) -> impl Iterator<Item = &'static str> + '_
Returns an iterator over registered workflow type names.